@@ -35,27 +35,14 @@ import multiprocessing
 
 import matplotlib.pyplot as plt
 import numpy as np
-import psutil
 import scipy as sp
 from matplotlib import cm, rcParams
 
-num_max_processors = multiprocessing.cpu_count()
-
-freq_max = psutil.cpu_freq()[2]
-info_memory = psutil.virtual_memory()[0] / 1024**3
-memory_available = psutil.virtual_memory(
-).available * 100 / psutil.virtual_memory().total
-
-num_max_processors = multiprocessing.cpu_count()
-
-print("number of processors: {}".format(num_max_processors))
-print("total memory        : {:1.1f} Gb".format(info_memory))
-print("available memory    : {:1.0f} %".format(memory_available))
-print("max frequency       : {:1.0f} GHz".format(freq_max))
+from .config import CONF_DRAWING
 
 __author__ = """Luis Miguel Sanchez Brea"""
 __email__ = 'optbrea@ucm.es'
-__version__ = '0.0.12'
+__version__ = '0.1.1'
 
 name = 'diffractio'
 
@@ -69,20 +56,11 @@ seconds = 1.
 eps = 1e-6
 num_decimals = 4
 
-no_date = False  # for test folder
-
-params_drawing = dict()
-params_drawing['color_intensity'] = cm.gist_heat  # cm.gist_heat  #cm.hot
-params_drawing['color_amplitude'] = cm.jet
-# cm.hsv  # cm.twilight #cm.twilight_shifted
-params_drawing['color_phase'] = cm.twilight
-params_drawing['color_real'] = cm.seismic
-params_drawing['color_stokes'] = cm.seismic
-params_drawing['percentaje_intensity'] = 0.005
-rcParams['figure.figsize'] = [4, 4]
-rcParams['figure.dpi'] = 125
+no_date = False  # for test
 
 now = datetime.datetime.now()
 date_test = now.strftime("%Y-%m-%d_%H")
 
 number_types = (int, float, complex, np.int32, np.float64)
+
+num_max_processors = multiprocessing.cpu_count()
