@@ -18,7 +18,7 @@ There are also some secondary atributes:
 *Class for unidimensional scalar fields*
 
 *Definition of a scalar field*
-    * instantiation, clear_field, print
+    * instantiation, duplicate,  clear_field, print
     * add, substract sources
     * multiply masks and sources
     * save and load data
@@ -49,27 +49,31 @@ There are also some secondary atributes:
 
 """
 
+import copy
 import copyreg
+import multiprocessing
 import time
 import types
 
-from numpy import (angle, array, concatenate, exp, linspace, pi, shape, sqrt,
-                   zeros)
+from numpy import (angle, array, concatenate, exp, linspace, pi, shape, sqrt, zeros)
 from numpy.lib.scimath import sqrt as csqrt
 from scipy.fftpack import fft, fftshift, ifft
 from scipy.interpolate import interp1d
 from scipy.special import hankel1
 
-from . import degrees, mm, np, num_max_processors, plt
+from . import degrees, mm, np, plt
+
 from .utils_common import get_date, load_data_common, save_data_common
 from .utils_drawing import normalize_draw
-from .utils_math import fft_filter, get_edges, nearest
+from .utils_math import fft_filter, get_edges, nearest, reduce_to_1, Bluestein_dft_x
 from .utils_multiprocessing import (_pickle_method, _unpickle_method,
                                     execute_multiprocessing)
-from .utils_optics import field_parameters, normalize
+from .utils_optics import field_parameters, normalize_field
 
 copyreg.pickle(types.MethodType, _pickle_method, _unpickle_method)
 
+num_max_processors = multiprocessing.cpu_count()
+
 
 class Scalar_field_X(object):
     """Class for unidimensional scalar fields.
@@ -112,10 +116,10 @@ class Scalar_field_X(object):
         Imax = (np.abs(self.u)**2).max()
         phase_min = (np.angle(self.u)).min() / degrees
         phase_max = (np.angle(self.u)).max() / degrees
-        print("{}\n - x:  {},   u:  {}".format(self.type, self.x.shape,
-                                               self.u.shape))
-        print(" - xmin:       {:2.2f} um,  xmax:      {:2.2f} um".format(
-            self.x[0], self.x[-1]))
+        print("{}\n - x:  {},   u:  {}".format(self.type, self.x.shape, self.u.shape))
+        print(
+            " - xmin:       {:2.2f} um,  xmax:      {:2.2f} um,  Dx:   {:2.2f} um"
+            .format(self.x[0], self.x[-1], self.x[1] - self.x[0]))
         print(" - Imin:       {:2.2f},     Imax:      {:2.2f}".format(
             Imin, Imax))
         print(" - phase_min:  {:2.2f} deg, phase_max: {:2.2f} deg".format(
@@ -123,9 +127,9 @@ class Scalar_field_X(object):
 
         print(" - wavelength: {:2.2f} um".format(self.wavelength))
         print(" - date:       {}".format(self.date))
-        print(" - info:       {}".format(self.info))
-
-        return ""
+        if self.info != "":
+            print(" - info:       {}".format(self.info))
+        return ("")
 
     def __add__(self, other, kind='standard'):
         """Adds two Scalar_field_x. For example two light sources or two masks.
@@ -138,6 +142,8 @@ class Scalar_field_X(object):
 
         Returns:
             Scalar_field_X: `u3 = u1 + u2`
+
+        TODO: improve to have better usage
         """
 
         u3 = Scalar_field_X(self.x, self.wavelength)
@@ -165,8 +171,7 @@ class Scalar_field_X(object):
         Returns:
             Scalar_field_X: `u3 = u1 - u2`
 
-        TODO:
-            It can be improved for maks (not having less than 1)
+        TODO: It can be improved for masks (not having less than 1)
         """
 
         u3 = Scalar_field_X(self.x, self.wavelength)
@@ -187,6 +192,27 @@ class Scalar_field_X(object):
         new_field.u = self.u * other.u
         return new_field
 
+    def duplicate(self, clear=False):
+        """Duplicates the instance
+
+        Parameters:
+            clear (bool): If True, clears the self.u argument, else it keeps the same than in self.
+
+        Returns
+            new_instance (scalar_field_X): duplicated instance.
+        """
+
+        new_field = copy.deepcopy(self)
+        if clear is True:
+            new_field.clear_field()
+        return new_field
+
+    def reduce_to_1(self):
+        """All the values greater than 1 pass to 1. This is used for Scalar_masks when we add two masks.
+        """
+
+        self = reduce_to_1(self)
+
     def clear_field(self):
         """Removes the field so that self.u = 0. """
         self.u = np.zeros_like(self.u, dtype=complex)
@@ -206,8 +232,7 @@ class Scalar_field_X(object):
             (str): filename. If False, file could not be saved.
         """
         try:
-            final_filename = save_data_common(self, filename, add_name,
-                                              description, verbose)
+            final_filename = save_data_common(self, filename, add_name, description, verbose)
             return final_filename
         except:
             return False
@@ -231,11 +256,7 @@ class Scalar_field_X(object):
         if verbose is True:
             print(dict0.keys())
 
-    def cut_resample(self,
-                     x_limits='',
-                     num_points=[],
-                     new_field=False,
-                     interp_kind='quadratic'):
+    def cut_resample(self, x_limits='', num_points=[], new_field=False, interp_kind='linear'):
         """Cuts the field to the range (x0,x1). If one of this x0,x1 positions is out of the self.x range it does nothing.
         It is also valid for resampling the field, just write x0,x1 as the limits of self.x
 
@@ -266,17 +287,9 @@ class Scalar_field_X(object):
 
         if num_points not in ([], '', 0, None):
             x_new = linspace(x0, x1, num_points)
-            f_interp_abs = interp1d(self.x,
-                                    np.abs(self.u),
-                                    kind=interp_kind,
-                                    bounds_error=False,
-                                    fill_value=0)
+            f_interp_abs = interp1d(self.x, np.abs(self.u), kind=interp_kind, bounds_error=False, fill_value=0)
 
-            f_interp_phase = interp1d(self.x,
-                                      np.imag(self.u),
-                                      kind=interp_kind,
-                                      bounds_error=False,
-                                      fill_value=0)
+            f_interp_phase = interp1d(self.x, np.imag(self.u), kind=interp_kind, bounds_error=False, fill_value=0)
 
             u_new_abs = f_interp_abs(x_new)
             u_new_phase = f_interp_phase(x_new)
@@ -330,17 +343,9 @@ class Scalar_field_X(object):
             t1.x = t1.x - (t1.x[0] + t1.x[-1]) / 2 + x0_mask1
 
         # interpolation is different for real and imag
-        f_interp_real = interp1d(t1.x,
-                                 np.real(t1.u),
-                                 kind='nearest',
-                                 bounds_error=False,
-                                 fill_value=0)
+        f_interp_real = interp1d(t1.x, np.real(t1.u), kind='nearest', bounds_error=False, fill_value=0)
 
-        f_interp_imag = interp1d(t1.x,
-                                 np.imag(t1.u),
-                                 kind='nearest',
-                                 bounds_error=False,
-                                 fill_value=0)
+        f_interp_imag = interp1d(t1.x, np.imag(t1.u), kind='nearest', bounds_error=False, fill_value=0)
 
         # interpolates all the range
         u_new_real = f_interp_real(self.x)
@@ -364,10 +369,7 @@ class Scalar_field_X(object):
             kind_position (str): 'left', 'center': positions are at left or center.
         """
 
-        self.insert_mask(t1,
-                         x_pos[0],
-                         clean=clean,
-                         kind_position=kind_position)
+        self.insert_mask(t1, x_pos[0], clean=clean, kind_position=kind_position)
 
         for xi in x_pos[1:]:
             self.insert_mask(t1, xi, clean=False, kind_position=kind_position)
@@ -407,7 +409,7 @@ class Scalar_field_X(object):
         num_x = self.x.size
         delta_x = self.x[1] - self.x[0]
         freq_nyquist_x = 1 / (2 * delta_x)
-        kx = linspace(-freq_nyquist_x, freq_nyquist_x, num_x) * self.wavelength
+        kx = np.linspace(-freq_nyquist_x, freq_nyquist_x, num_x) * self.wavelength
 
         if z in (None, '', [], 0):
             x_new = kx  # exit in angles (degrees)
@@ -429,13 +431,7 @@ class Scalar_field_X(object):
             self.u = ttf1
             self.x = x_new
 
-    def ifft(self,
-             z=None,
-             shift=True,
-             remove0=True,
-             matrix=False,
-             new_field=False,
-             verbose=False):
+    def ifft(self, z=None, shift=True, remove0=True, matrix=False, new_field=False, verbose=False):
         """Inverse Fast Fourier Transform (ifft) of the field.
 
         Parameters:
@@ -463,7 +459,7 @@ class Scalar_field_X(object):
         num_x = self.x.size
         delta_x = self.x[1] - self.x[0]
         freq_nyquist_x = 1 / (2 * delta_x)
-        kx = linspace(-freq_nyquist_x, freq_nyquist_x, num_x) * self.wavelength
+        kx = np.linspace(-freq_nyquist_x, freq_nyquist_x, num_x) * self.wavelength
 
         if z in (None, '', [], 0):
             x_new = kx  # exit in angles (radians)
@@ -486,15 +482,7 @@ class Scalar_field_X(object):
             if verbose is True:
                 print("x0={},x1={}".format(x_new[0], x_new[-1]))
 
-    def _RS_(self,
-             z,
-             n,
-             matrix=False,
-             new_field=True,
-             fast=False,
-             kind='z',
-             xout=None,
-             verbose=True):
+    def _RS_(self, z, n, matrix=False, new_field=True, fast=False, kind='z', xout=None, verbose=True):
         """Fast-Fourier-Transform  method for numerical integration of diffraction Rayleigh-Sommerfeld formula. `Thin Element Approximation` is considered for determining the field just after the mask:
 
         :math:`\mathbf{E}_{0}(\zeta,\eta)=t(\zeta,\eta)\mathbf{E}_{inc}(\zeta,\eta)`
@@ -518,7 +506,7 @@ class Scalar_field_X(object):
             (Scalar_field_X or None): if New_field is True Scalar_field_X, else None
 
         References:
-                Applied Optics vol 45 num 6 pp. 1102-1110 (2006)
+                F. Shen and A. Wang, “Fast-Fourier-transform based numerical integration method for the Rayleigh-Sommerfeld diffraction formula,” Appl. Opt., vol. 45, no. 6, pp. 1102–1110, 2006.
         """
 
         if xout is None:
@@ -530,11 +518,11 @@ class Scalar_field_X(object):
         dx = xout[1] - xout[0]
 
         # parametro de quality
-        dr_real = sqrt(dx**2)
-        rmax = sqrt((xout**2).max())
+        dr_real = dx
+        rmax = xout.max()
         dr_ideal = sqrt((self.wavelength / n)**2 + rmax**2 + 2 *
                         (self.wavelength / n) * sqrt(rmax**2 + z**2)) - rmax
-        self.quality = dr_ideal / dr_real
+        self.quality = dr_ideal / dr_real / np.sqrt(2)
 
         if verbose is True:
             if (self.quality.min() > 1):
@@ -543,16 +531,21 @@ class Scalar_field_X(object):
                 print('- Needs denser sampling: factor {:2.2f}'.format(
                     self.quality))
 
-        # matrix W para integracion simpson
-        a = [2, 4]
-        num_rep = int(round((nx) / 2) - 1)
+        precise = False
 
-        b = array(a * num_rep)
-        W = concatenate(((1, ), b, (2, 1))) / 3.
+        if precise:
+            # matrix W para integracion simpson
+            a = [2, 4]
+            num_rep = int(round((nx) / 2) - 1)
 
-        if float(nx) / 2 == round(nx / 2):  # es par
-            i_central = num_rep + 1
-            W = concatenate((W[:i_central], W[i_central + 1:]))
+            b = array(a * num_rep)
+            W = concatenate(((1, ), b, (2, 1))) / 3.
+
+            if float(nx) / 2 == round(nx / 2):  # es par
+                i_central = num_rep + 1
+                W = concatenate((W[:i_central], W[i_central + 1:]))
+        else:
+            W = 1
 
         # field
         U = zeros(2 * nx - 1, dtype=complex)
@@ -589,15 +582,7 @@ class Scalar_field_X(object):
             # self.u = Usalida / sqrt(z)
             self.u = Usalida
 
-    def RS(self,
-           z=10 * mm,
-           n=1,
-           matrix=False,
-           new_field=True,
-           fast=False,
-           amplification=1,
-           kind='z',
-           verbose=True):
+    def RS(self, z=10 * mm, n=1, matrix=False, new_field=True, fast=False, amplification=1, kind='z', verbose=True):
         """Fast-Fourier-Transform  method for numerical integration of diffraction Rayleigh-Sommerfeld formula. Is we have a field of size N*M, the result of propagation is also a field N*M. Nevertheless, there is a parameter `amplification` which allows us to determine the field in greater observation planes (jN)x(jM).
 
         Parameters:
@@ -631,16 +616,8 @@ class Scalar_field_X(object):
 
         u_field = np.zeros_like(x0, dtype=complex)
         qualities = np.zeros((amplification))
-        for i, xi in zip(list(range(len(positions_x))),
-                         np.flipud(positions_x)):
-            u3 = self._RS_(z=z,
-                           n=n,
-                           matrix=False,
-                           new_field=True,
-                           fast=fast,
-                           kind=kind,
-                           xout=xi,
-                           verbose=verbose)
+        for i, xi in zip(list(range(len(positions_x))), np.flipud(positions_x)):
+            u3 = self._RS_(z=z, n=n, matrix=False, new_field=True, fast=fast, kind=kind, xout=xi, verbose=verbose)
             xshape = slice(i * num_pixels, (i + 1) * num_pixels)
             u_field[xshape] = u3.u
             qualities[i] = u3.quality
@@ -658,23 +635,122 @@ class Scalar_field_X(object):
             self.u = u_field
             self.quality = qualities.min()
 
-    def normalize(self, kind='intensity', new_field=False):
+    def CZT(self, z, xout=None, verbose=False):
+        """Chirped z-transform.
+
+        Parameters:
+            z (float or np.array): diffraction distance
+            xout (float or np.array): x array with positions of the output plane
+            verbose (bool): If True it prints information.
+
+
+        Returns:
+            u_out: Complex amplitude of the outgoing light beam
+        """
+
+        if xout is None:
+            xout = self.x
+
+        k = 2 * np.pi / self.wavelength
+
+        if isinstance(z, (float, int)):
+            num_z = 1
+            # print("z = 0 dim")
+        else:
+            num_z = len(z)
+            # print("z = 1 dim")
+
+        if isinstance(xout, (float, int)):
+            num_x = 1
+            # print("x = 0 dim")
+            xstart = xout
+            xend = xout
+
+        else:
+            num_x = len(xout)
+            # print("x = 1 dim")
+
+            xstart = xout[0]
+            xend = xout[-1]
+
+        dx = self.x[1] - self.x[0]
+
+        if num_z == 1:
+
+            delta_out = np.zeros(2)
+            if num_x > 1:
+                delta_out[0] = (xend - xstart) / (num_x - 1)
+
+            # calculating scalar diffraction below
+            F0 = np.exp(1j * k * z) / (1j * self.wavelength * z) * np.exp(
+                1j * k / 2 / z * (xout**2))
+            F = np.exp(1j * k / 2 / z * (self.x**2))
+            u0 = self.u * F
+
+            fs = self.wavelength * z / dx  # dimension of the imaging plane
+            fx1 = xstart + fs / 2
+            fx2 = xend + fs / 2
+            u0 = Bluestein_dft_x(u0, fx1, fx2, fs, num_x)
+
+            k_factor = np.sqrt(z * self.wavelength) * dx
+
+            u0 = F0 * u0 * k_factor
+            # obtain the complex amplitude of the outgoing light beam
+
+            if num_x == 1:
+                return u0
+            else:
+                u_out = Scalar_field_X(xout, self.wavelength)
+                u_out.u = u0
+
+        else:
+            u_zs = np.zeros((len(z), num_x), dtype=complex)
+            num_z = len(z)
+            for i, z_now in enumerate(z):
+                if verbose is True:
+                    print("{}/{}".format(i, num_z), sep="\r", end="\r")
+                delta_out = np.zeros(2)
+                if num_x > 1:
+                    delta_out[0] = (xend - xstart) / (num_x - 1)
+
+                # calculating scalar diffraction below
+                F0 = np.exp(1j * k * z_now) / (
+                    1j * self.wavelength * z_now) * np.exp(1j * k / 2 / z_now * (xout**2))
+                F = np.exp(1j * k / 2 / z_now * (self.x**2))
+                u0 = self.u * F
+
+                fs = self.wavelength * z_now / dx  # dimension of the imaging plane
+                fx1 = xstart + fs / 2
+                fx2 = xend + fs / 2
+                u0 = Bluestein_dft_x(u0, fx1, fx2, fs, num_x)
+
+                u0 = F0 * u0  # obtain the complex amplitude of the outgoing light beam
+
+                k_factor = np.sqrt(z_now * self.wavelength) * dx
+
+                u_zs[i, :] = u0 * k_factor
+
+            if num_x == 1:
+                from diffractio.scalar_fields_Z import Scalar_field_Z
+                u_out = Scalar_field_Z(z=z, wavelength=self.wavelength)
+                u_out.u = u_zs
+                return u_out
+            else:
+                from diffractio.scalar_fields_XZ import Scalar_field_XZ
+                u_out = Scalar_field_XZ(xout, z, self.wavelength)
+                u_out.u = u_zs.transpose()
+
+        return u_out
+
+    def normalize(self, new_field=False):
         """Normalizes the field so that intensity.max()=1.
 
         Parameters:
-            kind (str): 'intensity, 'amplitude', 'logarithm'... other.. Normalization technique
-            new_field (bool): If False the computation goes to self.u. If True a new instance is produced
+            new_field (bool): If False the computation goes to self.u. If True a new instance is produced.
         Returns
             u (numpy.array): normalized optical field
         """
-        u_new = normalize(self.u, kind)
-
-        if new_field is False:
-            self.u = u_new
-        else:
-            field_output = Scalar_field_X(self.x, self.wavelength)
-            field_output.u = u_new
-            return field_output
+        return normalize_field(self, new_field)
 
     def MTF(self, kind='mm', has_draw=True):
         """Computes the MTF of a field,.
@@ -741,18 +817,13 @@ class Scalar_field_X(object):
         Returns:
             (float): average intensity.
         """
-        num_data = len(self.x)
-        average_intensity = (np.abs(self.u)**2).sum() / (num_data)
+        average_intensity = (np.abs(self.u)**2).mean()
         if verbose is True:
             print("average intensity={} W/m").format(average_intensity)
 
         return average_intensity
 
-    def get_edges(self,
-                  kind_transition='amplitude',
-                  min_step=0,
-                  verbose=False,
-                  filename=''):
+    def get_edges(self, kind_transition='amplitude', min_step=0, verbose=False, filename=''):
         """Determine locations of edges for a binary mask.
 
         Parameters:
@@ -771,13 +842,7 @@ class Scalar_field_X(object):
             self.x, self.u, kind_transition, min_step, verbose, filename)
         return pos_transitions, type_transitions, raising, falling
 
-    def draw(self,
-             kind='intensity',
-             logarithm=False,
-             normalize=False,
-             cut_value=None,
-             filename='',
-             scale=''):
+    def draw(self, kind='intensity', logarithm=False, normalize=False, cut_value=None, filename='', scale=''):
         """Draws X field. There are several data from the field that are extracted, depending of 'kind' parameter.
 
         Parameters:
@@ -971,11 +1036,7 @@ def WPM_schmidt_kernel(u, n, k0, k_perp2, dz):
     return u_final
 
 
-def polychromatic_multiprocessing(function_process,
-                                  wavelengths,
-                                  spectrum,
-                                  num_processors=num_max_processors,
-                                  verbose=False):
+def polychromatic_multiprocessing(function_process, wavelengths, spectrum, num_processors=num_max_processors, verbose=False):
     """
     It performs an analysis of polychromatic light. It needs a function with only one input parameter: wavelength.
     It determines the intensity for each wavelength and the final results is the summation of the intensities.
@@ -997,8 +1058,7 @@ def polychromatic_multiprocessing(function_process,
         spectrum = np.ones_like(wavelengths)
 
     if type(wavelengths) in (list, np.ndarray):
-        u_s, time_proc = execute_multiprocessing(function_process, wavelengths,
-                                                 num_processors, verbose)
+        u_s, time_proc = execute_multiprocessing(function_process, wavelengths, num_processors, verbose)
         print(len(u_s))
         intensity = np.zeros_like(u_s[0].u, dtype=float)
         for i in range(len(wavelengths)):
@@ -1014,10 +1074,7 @@ def polychromatic_multiprocessing(function_process,
     return intensity, u_s, time_proc
 
 
-def extended_source_multiprocessing(function_process,
-                                    x0s,
-                                    num_processors=num_max_processors,
-                                    verbose=False):
+def extended_source_multiprocessing(function_process, x0s, num_processors=num_max_processors, verbose=False):
     """
     It performs an analysis of extendes source light. It needs a function with only an input parameter, that is x0s positions of sources. It determines the intensity for each wavelength and it is added.
 
@@ -1034,8 +1091,7 @@ def extended_source_multiprocessing(function_process,
     """
 
     if type(x0s) in (list, np.ndarray):
-        u_s, time_proc = execute_multiprocessing(function_process, x0s,
-                                                 num_processors, verbose)
+        u_s, time_proc = execute_multiprocessing(function_process, x0s, num_processors, verbose)
         intensity = np.zeros_like(u_s[0].u, dtype=float)
         for i in range(len(x0s)):
             intensity = intensity + np.abs(u_s[i].u)**2
@@ -1052,12 +1108,7 @@ def extended_source_multiprocessing(function_process,
     return intensity, u_s, time_proc
 
 
-def extended_polychromatic_source(function_process,
-                                  x0s,
-                                  wavelengths,
-                                  spectrum,
-                                  num_processors=num_max_processors,
-                                  verbose=False):
+def extended_polychromatic_source(function_process, x0s, wavelengths, spectrum, num_processors=num_max_processors, verbose=False):
     """ It performs an analysis of extendes source light. It needs a function with only an input parameter, that is x0s positions of sources. It determines the intensity for each wavelength and it is added.
 
     Parameters:
@@ -1067,11 +1118,8 @@ def extended_polychromatic_source(function_process,
         spectrum (array): weights for the spectrum. If None: uniform spectrum, else array with the same dimension as wavelengths
         num_processors (int): number of processors for the computation
         verbose (bool): if True send information to shell
-
-    Returns:
-        - intensity (array, complex): intensity = intensity + spectrum[i] * np.abs(u_s[i].u)**2
-        - u_s (Scalar_field_X): fields for each wavelength
-        - time_proc (float): time interval in the processing
+     Returns:        - intensity (array, complex): intensity = intensity + spectrum[i] * np.abs(u_s[i].u)**2
+        - u_s (Scalar_field_X): fields for each wavelength         - time_proc (float): time interval in the processing 
     """
 
     dict_Parameters = []
@@ -1080,8 +1128,7 @@ def extended_polychromatic_source(function_process,
             dict_Parameters.append(
                 dict(x0=x0, wavelength=wavelength, ij=(i, j)))
 
-    u_s, time_proc = execute_multiprocessing(function_process, dict_Parameters,
-                                             num_processors, verbose)
+    u_s, time_proc = execute_multiprocessing(function_process, dict_Parameters, num_processors, verbose)
     intensity = np.zeros_like(u_s[0].u, dtype=float)
     for k in range(len(u_s)):
         # print( len(u_s), dict_Parameters[k]['ij'])
