@@ -19,6 +19,7 @@ The magnitude is related to microns: `micron = 1.`
 *Class for unidimensional scalar fields*
 
 *Definition of a scalar field*
+    * instantiation, duplicate
     * load and save data
     * to_Scalar_field_XY
     * xy_2_xyz
@@ -40,6 +41,7 @@ The magnitude is related to microns: `micron = 1.`
     * video
 
 """
+import copy
 import copyreg
 import os
 import sys
@@ -50,17 +52,17 @@ from multiprocessing import Pool
 import matplotlib.animation as anim
 from numpy import cos, diff, gradient, sin
 from scipy.fftpack import fft2, ifft2
-from scipy.interpolate import RectBivariateSpline, RegularGridInterpolator
-from scipy.signal import correlate2d
+from scipy.interpolate import RegularGridInterpolator
 
-from . import degrees, eps, mm, np, num_max_processors, params_drawing, plt
+from . import degrees, mm, np, plt, num_max_processors
+from .config import CONF_DRAWING
 from .scalar_fields_XY import PWD_kernel, Scalar_field_XY, WPM_schmidt_kernel
 from .scalar_fields_XZ import Scalar_field_XZ
 from .utils_common import get_date, load_data_common, save_data_common
-from .utils_drawing import normalize_draw, prepare_drawing
-from .utils_math import get_k, ndgrid, nearest
+from .utils_drawing import normalize_draw
+from .utils_math import get_k, ndgrid, nearest, reduce_to_1
 from .utils_multiprocessing import _pickle_method, _unpickle_method
-from .utils_optics import FWHM2D, beam_width_2D, field_parameters
+from .utils_optics import FWHM2D, beam_width_2D, field_parameters, normalize_field
 
 copyreg.pickle(types.MethodType, _pickle_method, _unpickle_method)
 
@@ -84,6 +86,7 @@ class Scalar_field_XYZ(object):
         self.n_background (float): background refraction index.
         self.n (numpy.array): refraction index. Same dimensions than self.u.
     """
+
     def __init__(self,
                  x=None,
                  y=None,
@@ -100,7 +103,7 @@ class Scalar_field_XYZ(object):
         self.fast = True
         self.quality = 0
         self.borders = None
-        self.params_drawing = params_drawing
+        self.CONF_DRAWING = CONF_DRAWING
 
         if x is not None and z is not None:
             self.X, self.Y, self.Z = ndgrid(x, y, z)
@@ -155,22 +158,24 @@ class Scalar_field_XYZ(object):
         phase_max = (np.angle(self.u)).max() / degrees
         print("{}\n - x:  {},   y:  {},  z:  {},   u:  {}".format(
             self.type, self.x.shape, self.y.shape, self.z.shape, self.u.shape))
-        print(" - xmin:       {:2.2f} um,  xmax:      {:2.2f} um".format(
-            self.x[0], self.x[-1]))
-        print(" - ymin:       {:2.2f} um,  ymax:      {:2.2f} um".format(
-            self.y[0], self.y[-1]))
-        print(" - zmin:       {:2.2f} um,  zmax:      {:2.2f} um".format(
-            self.z[0], self.z[-1]))
+        print(
+            " - xmin:       {:2.2f} um,  xmax:      {:2.2f} um,  Dx:   {:2.2f} um"
+            .format(self.x[0], self.x[-1], self.x[1] - self.x[0]))
+        print(
+            " - ymin:       {:2.2f} um,  ymax:      {:2.2f} um,  Dy:   {:2.2f} um"
+            .format(self.y[0], self.y[-1], self.y[1] - self.y[0]))
+        print(
+            " - zmin:       {:2.2f} um,  zmax:      {:2.2f} um,  Dz:   {:2.2f} um"
+            .format(self.z[0], self.z[-1], self.z[1] - self.z[0]))
         print(" - Imin:       {:2.2f},     Imax:      {:2.2f}".format(
             Imin, Imax))
         print(" - phase_min:  {:2.2f} deg, phase_max: {:2.2f} deg".format(
             phase_min, phase_max))
-
         print(" - wavelength: {:2.2f} um".format(self.wavelength))
         print(" - date:       {}".format(self.date))
-        print(" - info:       {}".format(self.info))
-
-        return ""
+        if self.info != "":
+            print(" - info:       {}".format(self.info))
+        return ("")
 
     def __add__(self, other, kind='standard'):
         """Adds two Scalar_field_XYZ. For example two light sources or two masks.
@@ -210,8 +215,7 @@ class Scalar_field_XYZ(object):
         Returns:
             Scalar_field_X: `u3 = u1 - u2`
 
-        # TODO:
-            It can be improved for maks (not having less than 1)
+        # TODO: It can be improved for maks (not having less than 1)
         """
 
         u3 = Scalar_field_XYZ(self.x, self.y, self.z, self.wavelength,
@@ -278,6 +282,34 @@ class Scalar_field_XYZ(object):
 
         return Xrot, Yrot, Zrot
 
+    def normalize(self, new_field=False):
+        """Normalizes the field so that intensity.max()=1.
+
+        Parameters:
+            new_field (bool): If False the computation goes to self.u. If True a new instance is produced
+        Returns
+            u (numpy.array): normalized optical field
+        """
+        return normalize_field(self, new_field)
+
+    def duplicate(self, clear=False):
+        """Duplicates the instance"""
+        # new_field = Scalar_field_XYZ(self.x, self.y, self.z, self.wavelength,
+        #                              self.n_background)
+        # new_field.n = self.n
+        # new_field.u = self.u
+        # return new_field
+        new_field = copy.deepcopy(self)
+        if clear is True:
+            new_field.clear_field()
+        return new_field
+
+    def reduce_to_1(self):
+        """All the values greater than 1 pass to 1. This is used for Scalar_masks when we add two masks.
+        """
+
+        self = reduce_to_1(self)
+
     def clear_field(self):
         """clear field."""
 
@@ -460,12 +492,13 @@ class Scalar_field_XYZ(object):
 
         self.u0 = u0
 
-        if z0 in (None, '', []):
-            self.u[:, :, 0] = self.u[:, :, 0] + u0.u.transpose()
+        if u0.x.shape == self.x.shape:
+            if z0 in (None, '', []):
+                self.u[:, :, 0] = self.u[:, :, 0] + u0.u.transpose()
 
-        else:
-            iz, _, _ = nearest(self.z, z0)
-            self.u[:, :, iz] = self.u[:, :, iz] + u0.u.tranpose()
+            else:
+                iz, _, _ = nearest(self.z, z0)
+                self.u[:, :, iz] = self.u[:, :, iz] + u0.u.tranpose()
 
     def final_field(self):
         """Returns the final field as a Scalar_field_XYZ."""
@@ -821,8 +854,7 @@ class Scalar_field_XYZ(object):
             class (bool): If True it returns a class
             matrix (bool): If True it returns a matrix
 
-        TODO:
-            Simplify and change variable name clase
+        TODO: Simplify and change variable name clase
         """
         if is_class is True:
             field_output = Scalar_field_XY(x=self.x,
@@ -855,8 +887,6 @@ class Scalar_field_XYZ(object):
             class (bool): If True it returns a class
             matrix (bool): If True it returns a matrix
 
-        TODO:
-            Simplify and change variable name clase
         """
         if is_class is True:
             field_output = Scalar_field_XZ(x=self.x,
@@ -889,8 +919,6 @@ class Scalar_field_XYZ(object):
             class (bool): If True it returns a class
             matrix (bool): If True it returns a matrix
 
-        TODO:
-            Simplify and change variable name clase
         """
         if is_class is True:
             field_output = Scalar_field_XZ(x=self.y,
@@ -899,13 +927,13 @@ class Scalar_field_XYZ(object):
             if ix0 is None:
                 ix, tmp1, tmp2 = nearest(self.x, x0)
             else:
-                iy = iy0
+                iy = ix0
             field_output.u = np.squeeze(self.u[ix, :, :])
             return field_output
 
         if matrix is True:
             if ix0 is None:
-                ix, tmp1, tmp2 = nearest(self.x, x0)
+                ix, _, _ = nearest(self.x, x0)
             else:
                 ix = ix0
             return np.squeeze(self.u[ix, :, :])
@@ -956,10 +984,28 @@ class Scalar_field_XYZ(object):
 
         return self.z, y
 
+    def average_intensity(self, has_draw=False):
+        """Returns average intensity as: (np.abs(self.u)**2).mean()
+
+        Parameters:
+            verbose(bool): If True prints data.
+
+        Returns:
+            intensity_mean (np.array): z array with average intensity at each plane z.
+
+        """
+        intensity_mean = (np.abs(self.u)**2).mean(axis=2)
+        if has_draw is True:
+            plt.figure()
+            plt.imshow(intensity_mean)
+
+        return intensity_mean
+
     def beam_widths(self,
                     kind='FWHM2D',
                     has_draw=[True, False],
-                    percentaje=0.5,
+                    percentage=0.5,
+                    remove_background=None,
                     verbose=False):
         """Determines the widths of the beam
 
@@ -994,8 +1040,8 @@ class Scalar_field_XYZ(object):
                 dx, dy = FWHM2D(self.x,
                                 self.y,
                                 intensity,
-                                percentaje=percentaje,
-                                remove_background='min',
+                                percentage=percentage,
+                                remove_background=remove_background,
                                 has_draw=has_draw[1])
                 principal_axis = 0.
 
@@ -1180,11 +1226,13 @@ class Scalar_field_XYZ(object):
                     reduce_matrix=reduce_matrix)
 
     def draw_XZ(self,
+                kind='intensity',
                 y0=0 * mm,
                 logarithm=0,
                 normalize='',
                 draw_borders=False,
-                filename=''):
+                filename='',
+                **kwargs):
         """Longitudinal profile XZ at a given x0 value.
 
         Parameters:
@@ -1197,42 +1245,44 @@ class Scalar_field_XYZ(object):
 
         plt.figure()
         ufield = self.to_Scalar_field_XZ(y0=y0)
-        intensity = np.abs(ufield.u)**2
+        h1 = ufield.draw(kind, logarithm, normalize, draw_borders, filename,
+                         **kwargs)
+        # intensity = np.abs(ufield.u)**2
 
-        if logarithm == 1:
-            intensity = np.log(intensity + 1)
+        # if logarithm == 1:
+        #     intensity = np.log(intensity + 1)
 
-        if normalize == 'maximum':
-            intensity = intensity / intensity.max()
-        if normalize == 'area':
-            area = (self.x[-1] - self.x[0]) * (self.z[-1] - self.z[0])
-            intensity = intensity / area
-        if normalize == 'intensity':
-            intensity = intensity / (intensity.sum() / len(intensity))
+        # if normalize == 'maximum':
+        #     intensity = intensity / intensity.max()
+        # if normalize == 'area':
+        #     area = (self.x[-1] - self.x[0]) * (self.z[-1] - self.z[0])
+        #     intensity = intensity / area
+        # if normalize == 'intensity':
+        #     intensity = intensity / (intensity.sum() / len(intensity))
 
-        h1 = plt.imshow(intensity,
-                        interpolation='bilinear',
-                        aspect='auto',
-                        origin='lower',
-                        extent=[
-                            self.z[0] / 1000, self.z[-1] / 1000, self.y[0],
-                            self.y[-1]
-                        ])
-        plt.xlabel('z (mm)', fontsize=16)
-        plt.ylabel('x $(um)$', fontsize=16)
-        plt.title('intensity XZ', fontsize=20)
-        h1.set_cmap(
-            self.params_drawing['color_intensity'])  # OrRd # Reds_r gist_heat
-        plt.colorbar()
+        # h1 = plt.imshow(intensity,
+        #                 interpolation='bilinear',
+        #                 aspect='auto',
+        #                 origin='lower',
+        #                 extent=[
+        #                     self.z[0] / 1000, self.z[-1] / 1000, self.y[0],
+        #                     self.y[-1]
+        #                 ])
+        # plt.xlabel('z (mm)', fontsize=16)
+        # plt.ylabel('x $(um)$', fontsize=16)
+        # plt.title('intensity XZ', fontsize=20)
+        # h1.set_cmap(
+        #     self.CONF_DRAWING['color_intensity'])  # OrRd # Reds_r gist_heat
+        # plt.colorbar()
 
-        # -----------------     no functiona de momento -----------------
-        if draw_borders is True:
-            x_surface, y_surface, z_surface, x_draw_intensity, y_draw_intensity, z_draw_intensity = self.surface_detection(
-            )
-            plt.plot(y_draw_intensity, z_draw_intensity, 'w.', ms=2)
+        # # -----------------     no functiona de momento -----------------
+        # if draw_borders is True:
+        #     x_surface, y_surface, z_surface, x_draw_intensity, y_draw_intensity, z_draw_intensity = self.surface_detection(
+        #     )
+        #     plt.plot(y_draw_intensity, z_draw_intensity, 'w.', ms=2)
 
-        if not filename == '':
-            plt.savefig(filename, dpi=300, bbox_inches='tight', pad_inches=0.1)
+        # if not filename == '':
+        #     plt.savefig(filename, dpi=300, bbox_inches='tight', pad_inches=0.1)
 
         return h1
 
@@ -1279,20 +1329,9 @@ class Scalar_field_XYZ(object):
         plt.ylabel('y $(um)$', fontsize=16)
         plt.title('intensity YZ', fontsize=20)
         h1.set_cmap(
-            self.params_drawing['color_intensity'])  # OrRd # Reds_r gist_heat
+            self.CONF_DRAWING['color_intensity'])  # OrRd # Reds_r gist_heat
         plt.colorbar()
 
-        # -----------------     no functiona de momento -----------------
-        if draw_borders is True:
-            x_surface, y_surface, z_surface, x_draw_intensity, y_draw_intensity, z_draw_intensity = self.surface_detection(
-            )
-            plt.plot(y_draw_intensity, z_draw_intensity, 'w.', ms=2)
-
-        if not filename == '':
-            plt.savefig(filename, dpi=300, bbox_inches='tight', pad_inches=0.1)
-
-        return h1
-
     def draw_XYZ(self,
                  kind='intensity',
                  logarithm=False,
@@ -1313,13 +1352,6 @@ class Scalar_field_XYZ(object):
             print("slicerLM is not loaded.")
             is_slicer = False
 
-        try:
-            from mayavi import mlab
-            is_mayavi = True
-        except ImportError:
-            print("mayavi.mlab is not imported.")
-            is_mayavi = False
-
         if is_slicer:
             u_xyz_r = self.cut_resample(num_points=(128, 128, 128),
                                         new_field=True)
@@ -1350,8 +1382,7 @@ class Scalar_field_XYZ(object):
             normalize (bool): If True, max(intensity)=1
             maxintensity (float): maximum value of intensity
 
-        TODO:
-            Simplify, drawing
+        TODO: Simplify, drawing
             include kind and other parameters of draw
         """
 
@@ -1445,11 +1476,11 @@ class Scalar_field_XYZ(object):
             frame (bool): figure with or without axis.
             verbose (bool): If True prints
 
-        TODO:
-            Implement kind, now only intensity
+        TODO: Implement kind, now only intensity
             include logarithm and normalize
             check
         """
+
         def f(x, kind):
             # return x
             amplitude, intensity, phase = field_parameters(
@@ -1467,12 +1498,12 @@ class Scalar_field_XYZ(object):
                 return "no correct kind in video"
 
         if kind == 'intensity':
-            cmap1 = self.params_drawing['color_intensity']
+            cmap1 = self.CONF_DRAWING['color_intensity']
         elif kind == 'phase':
-            cmap1 = self.params_drawing['color_phase']
+            cmap1 = self.CONF_DRAWING['color_phase']
 
         elif kind == 'real':
-            cmap1 = self.params_drawing['color_real']
+            cmap1 = self.CONF_DRAWING['color_real']
 
         else:
             return "no correct kind in video"
