@@ -26,7 +26,7 @@ The magnitude is related to microns: `micron = 1.`
 *Class for XZ scalar fields*
 
 *Definition of a scalar field*
-    * instatiation, clean_refraction_index
+    * instatiation, duplicate, clean_refraction_index
     * save, load data
     * rotate_field, cut_resample,
 
@@ -45,8 +45,8 @@ The magnitude is related to microns: `micron = 1.`
     * draw
     * draw_refraction_index
     * draw_incident_field
-    * video_profiles
     * draw_profiles_interactive
+    * video
 
 *Parameters*
     * final_field
@@ -54,6 +54,7 @@ The magnitude is related to microns: `micron = 1.`
     * profile_transversal
 """
 
+import copy
 import copyreg
 import sys
 import time
@@ -68,20 +69,23 @@ from numpy.lib.scimath import sqrt as csqrt
 from scipy.fftpack import fft, fft2, fftshift, ifft, ifft2
 from scipy.interpolate import RectBivariateSpline
 
-from . import (degrees, eps, mm, np, num_max_processors, params_drawing, plt,
-               seconds, um)
+from . import np, plt
+from . import num_max_processors, degrees, eps, mm, seconds, um
+from .config import CONF_DRAWING
 from .scalar_fields_X import (PWD_kernel, Scalar_field_X, WPM_schmidt_kernel,
                               kernelRS, kernelRSinverse)
 from .scalar_masks_X import Scalar_mask_X
 from .scalar_sources_X import Scalar_source_X
 from .utils_common import get_date, load_data_common, save_data_common
 from .utils_drawing import normalize_draw, prepare_drawing, prepare_video
-from .utils_math import get_k, ndgrid, nearest, rotate_image
+from .utils_math import get_k, ndgrid, nearest, reduce_to_1, rotate_image
 from .utils_multiprocessing import _pickle_method, _unpickle_method
-from .utils_optics import FWHM1D, beam_width_1D, field_parameters
+from .utils_optics import FWHM1D, beam_width_1D, field_parameters, normalize_field
 
 copyreg.pickle(types.MethodType, _pickle_method, _unpickle_method)
 
+percentage_intensity_config = CONF_DRAWING['percentage_intensity']
+
 
 class Scalar_field_XZ(object):
     """Class for working with XZ scalar fields.
@@ -120,14 +124,13 @@ class Scalar_field_XZ(object):
         self.fast = False
         self.quality = 0
         self.borders = None  # borders at refraction index
-        self.params_drawing = params_drawing
+        self.CONF_DRAWING = CONF_DRAWING
 
         if x is not None and z is not None:
             self.X, self.Z = ndgrid(x, z)
             self.u0 = Scalar_field_X(x, wavelength)
             self.u = np.zeros_like(self.X, dtype=complex)
-            self.n = n_background * np.ones(np.shape(
-                self.X), dtype=complex)  # el indice de refracción
+            self.n = n_background * np.ones(np.shape(self.X), dtype=complex)
         else:
             self.X = None
             self.Z = None
@@ -148,10 +151,12 @@ class Scalar_field_XZ(object):
         phase_max = (np.angle(self.u)).max() / degrees
         print("{}\n - x:  {},   z:  {},   u:  {}".format(
             self.type, self.x.shape, self.z.shape, self.u.shape))
-        print(" - xmin:       {:2.2f} um,  xmax:      {:2.2f} um".format(
-            self.x[0], self.x[-1]))
-        print(" - zmin:       {:2.2f} um,  zmax:      {:2.2f} um".format(
-            self.z[0], self.z[-1]))
+        print(
+            " - xmin:       {:2.2f} um,  xmax:      {:2.2f} um,  Dx:   {:2.2f} um"
+            .format(self.x[0], self.x[-1], self.x[1] - self.x[0]))
+        print(
+            " - zmin:       {:2.2f} um,  zmax:      {:2.2f} um,  Dz:   {:2.2f} um"
+            .format(self.z[0], self.z[-1], self.z[1] - self.z[0]))
         print(" - Imin:       {:2.2f},     Imax:      {:2.2f}".format(
             Imin, Imax))
         print(" - phase_min:  {:2.2f} deg, phase_max: {:2.2f} deg".format(
@@ -201,8 +206,7 @@ class Scalar_field_XZ(object):
         Returns:
             Scalar_field_X: `u3 = u1 - u2`
 
-        TODO:
-            It can be improved for maks (not having less than 1)
+        TODO: It can be improved for maks (not having less than 1)
         """
 
         u3 = Scalar_field_XZ(self.x, self.z, self.wavelength,
@@ -232,6 +236,24 @@ class Scalar_field_XZ(object):
                                                      z0) * np.cos(angle)
         return Xrot, Zrot
 
+    def reduce_to_1(self):
+        """All the values greater than 1 pass to 1. This is used for Scalar_masks when we add two masks.
+        """
+
+        self = reduce_to_1(self)
+
+    def duplicate(self, clear=False):
+        """Duplicates the instance"""
+        # new_field = Scalar_field_XZ(self.x, self.z, self.wavelength,
+        #                             self.n_background)
+        # new_field.n = self.n
+        # new_field.u = self.u
+        # return new_field
+        new_field = copy.deepcopy(self)
+        if clear is True:
+            new_field.clear_field()
+        return new_field
+
     def rotate_field(self, angle, center_rotation, kind='all', n_background=1):
         """Rotate all the image a certain angle
 
@@ -275,6 +297,16 @@ class Scalar_field_XZ(object):
 
         self.n = self.n_background * np.ones_like(self.X, dtype=complex)
 
+    def normalize(self, new_field=False):
+        """Normalizes the field so that intensity.max()=1.
+
+        Parameters:
+            new_field (bool): If False the computation goes to self.u. If True a new instance is produced
+        Returns
+            u (numpy.array): normalized optical field
+        """
+        return normalize_field(self, new_field)
+
     def mask_field(self, size_edge=0):
         """
         mask the incident field at the edges, each edge is masked size_edge
@@ -289,7 +321,7 @@ class Scalar_field_XZ(object):
         mask.slit(x0=x_center, size=L - 2 * size_edge)
         self.u0.u = self.u0.u * mask.u
 
-    def filter_refraction_index(self,
+    def smooth_refraction_index(self,
                                 type_filter=2,
                                 pixels_filtering=10,
                                 max_diff_filter=0.1,
@@ -304,7 +336,7 @@ class Scalar_field_XZ(object):
             draw_check (bool): draw the differences.
 
         Returns:
-            (float): percentaje_filtered
+            (float): percentage_filtered
             (np.array): lineas_filtradas
 
         References:
@@ -326,6 +358,7 @@ class Scalar_field_XZ(object):
                     centerz - 1:centerz + 1] = 1
             filtro1 = filtro1 / sum(sum(filtro1))
             self.n = fftshift(ifft2(fft2(self.n) * fft2(filtro1)))
+            percentage_filtered = 0
         elif type_filter == 2:
             # Filtro 1D, solo ejecuta cuando hay diferencias de índice eje x
             lineas_filtradas = np.zeros_like(self.z)
@@ -344,7 +377,7 @@ class Scalar_field_XZ(object):
                     self.n[:, i] = fftshift(
                         ifft(fft(self.n[:, i]) * fft(filtro1)))
                     num_filtrados = num_filtrados + 1
-            percentaje_filtered = 100 * num_filtrados / len(self.z)
+            percentage_filtered = 100 * num_filtrados / len(self.z)
         elif type_filter == 3:
             # Filtro 1D, solo ejecuta cuando hay diferencias de índice eje z
             lineas_filtradas = np.zeros_like(self.x)
@@ -360,7 +393,7 @@ class Scalar_field_XZ(object):
                     self.n[i, :] = fftshift(
                         ifft(fft(self.n[i, :]) * fft(filtro1)))
                     num_filtrados = num_filtrados + 1
-            percentaje_filtered = 100 * num_filtrados / len(self.x)
+            percentage_filtered = 100 * num_filtrados / len(self.x)
 
         if draw_check is True:
             plt.figure()
@@ -385,24 +418,9 @@ class Scalar_field_XZ(object):
 
             plt.axis(extension)
             h1.set_cmap(cm.gray_r)
-            plt.title("filter_refraction_index: n variations", fontsize=24)
+            plt.title("smooth_refraction_index: n variations", fontsize=24)
 
-        return percentaje_filtered, lineas_filtradas
-
-    def discretize_refraction_index(self, n_layers):
-        """Takes a refraction index an discretize it according refraction indexes.
-
-        Parameters:
-            n_layers (np.array): array with refraction indexes to discretize
-        """
-        n = deepcopy(self.n)
-        for i in range(len(n_layers) - 1):
-            i_capa = np.bitwise_and(self.n >= n_layers[i],
-                                    self.n <= n_layers[i + 1])
-            n_central = (n_layers[i] + n_layers[i + 1]) / 2
-            n[i_capa] = n_central
-        self.n = n
-        return n
+        return percentage_filtered, lineas_filtradas
 
     def save_data(self, filename, add_name='', description='', verbose=False):
         """Common save data function to be used in all the modules.
@@ -576,10 +594,16 @@ class Scalar_field_XZ(object):
         u_final.u = self.u[:, -1]
         return u_final
 
-    def __BPM__(self, matrix=False, verbose=False):
+    def __BPM__(self,
+                has_edges=True,
+                pow_edge=80,
+                matrix=False,
+                verbose=False):
         """Beam propagation method (BPM).
 
         Parameters:
+            has_edges (bool): If True absorbing edges are used.
+            pow_edge (float): If has_edges, power of the supergaussian
             matrix (bool): if True returns matrix, else goes to self.u
             verbose (bool): shows data process by screen
 
@@ -615,8 +639,11 @@ class Scalar_field_XZ(object):
         phase1 = np.exp((-1j * deltaz * kx**2) / (2 * k0))
         # Campo en el índice de refracción
         field = np.zeros(np.shape(self.n), dtype=complex)
-        # Función supergausiana para eliminar rebotes en los edges
-        filter_edge = np.exp(-((pixelx) / (0.99 * 0.5 * numx))**90)  # 0.98
+
+        if has_edges:
+            # Función supergausiana para eliminar rebotes en los edges
+            filter_edge = np.exp(-((pixelx) /
+                                   (0.99 * 0.5 * numx))**pow_edge)  # 0.98
 
         field[:, 0] = field_z
         for k in range(0, numz):
@@ -624,12 +651,15 @@ class Scalar_field_XZ(object):
                 if sys.version_info.major == 3:
                     print("BPM: {}/{}".format(k, numz), sep="\r", end="\r")
                 else:
-                    print("BPM: {}/{}".format(k,
-                                              numz).format(k, numz))
+                    print("BPM: {}/{}".format(k, numz).format(k, numz))
 
             phase2 = np.exp(1j * self.n[:, k] * k0 * deltaz)
             field_z = ifft((fft(field_z) * phase1)) * phase2
-            field_z = field_z * filter_edge + self.u[:, k]
+            if has_edges:
+                field_z = field_z * filter_edge + self.u[:, k]
+            else:
+                field_z = field_z + self.u[:, k]
+
             field[:, k] = field_z
 
         if matrix is True:
@@ -637,10 +667,17 @@ class Scalar_field_XZ(object):
         else:
             self.u = field
 
-    def BPM(self, division=False, matrix=False, verbose=False):
+    def BPM(self,
+            has_edges=True,
+            pow_edge=80,
+            division=False,
+            matrix=False,
+            verbose=False):
         """Beam propagation method (BPM).
 
         Parameters:
+            has_edges (bool): If True absorbing edges are used.
+            pow_edge (float): If has_edges, power of the supergaussian
             division (False, int): If False nothing, else divides the BPM algorithm in several different executions. To avoid RAM problems
             matrix (bool): if True returns a matrix else
             verbose (bool): shows data process by screen
@@ -653,7 +690,9 @@ class Scalar_field_XZ(object):
 
         if division is False:
             # standard BPM _algorithm
-            self.__BPM__(matrix, verbose)
+            # self.__BPM__(matrix, verbose)
+
+            self.__BPM__(has_edges, pow_edge, matrix, verbose)
 
         else:
             # Here is the division of self.z in parts
@@ -661,12 +700,10 @@ class Scalar_field_XZ(object):
             uf = self.u0
             for i in range(num_executions):
                 if verbose is True:
-                    if sys.version_info.major == 3:
-                        print("{}/{}".format(i, num_executions),
-                              sep="\r",
-                              end="\r")
-                    else:
-                        print("{}/{}".format(i, num_executions))
+                    print("{}/{}".format(i, num_executions),
+                          sep="\r",
+                          end="\r")
+
                 sl = slice(i * division, (i + 1) * division)
                 ui = Scalar_field_XZ(x=self.x,
                                      z=self.z[sl],
@@ -675,7 +712,7 @@ class Scalar_field_XZ(object):
                 ui.n = self.n[:, sl]
                 ui.u0 = uf
 
-                ui.BPM()
+                ui.BPM(has_edges, pow_edge, matrix, verbose)
                 uf = ui.final_field().u
                 self.u[:, sl] = ui.u
 
@@ -736,8 +773,6 @@ class Scalar_field_XZ(object):
     def __RS_multiprocessing__(self, i):
         """Internal for multiprocessing
 
-        TODO:
-            It can be using a dict as input
         """
         if self.z.min() > 0:
             H = kernelRS(self.xtemp,
@@ -865,8 +900,8 @@ class Scalar_field_XZ(object):
             if sys.version_info.major == 3:
                 print("time in RS= {}. num proc= {}".format(
                     time2 - time1, num_processors),
-                    sep="\r",
-                    end="\r")
+                      sep="\r",
+                      end="\r")
             else:
                 print("time in RS= {}. num proc= {}".format(
                     time2 - time1, num_processors))
@@ -1147,7 +1182,7 @@ class Scalar_field_XZ(object):
             verbose (bool): If True prints info.
 
         Returns:
-
+            u_current, fields_BPM, transitions
         """
 
         # check which parts are constant
@@ -1198,6 +1233,23 @@ class Scalar_field_XZ(object):
 
         return np.abs(self.u)**2
 
+    def average_intensity(self, has_draw=False):
+        """Returns average intensity as: (np.abs(self.u)**2).mean()
+
+        Parameters:
+            has_draw(bool): If True draws data.
+
+        Returns:
+            intensity_mean (np.array): z array with average intensity at each plane z.
+
+        """
+        intensity_mean = (np.abs(self.u)**2).mean(axis=0)
+        if has_draw is True:
+            plt.figure()
+            plt.plot(self.x, intensity_mean)
+
+        return intensity_mean
+
     def check_intensity(self, draw=True, normalized=True):
         """
         Checks that intensity distribution is not lost by edges. It can be executed after a RS or BPM propagation.
@@ -1210,7 +1262,6 @@ class Scalar_field_XZ(object):
             (np.array): array with intensity I(z)
         """
 
-        # intensity_prof = np.sum((np.abs(self.u)**2) * np.real(self.n), axis=0)
         intensity_prof = np.sum((np.abs(self.u)**2), axis=0)
         I_max = intensity_prof[0]
         if normalized is True:
@@ -1399,6 +1450,7 @@ class Scalar_field_XZ(object):
              z_scale='um',
              edge_matrix=None,
              interpolation='spline36',
+             percentage_intensity=None,
              **kwargs):
         """Draws  XZ field.
 
@@ -1414,6 +1466,7 @@ class Scalar_field_XZ(object):
             z_scale (str): 'mm', 'um'
             edge_matrix (numpy.array): positions of borders
             interpolation(str): methods = [None, 'none', 'nearest', 'bilinear', 'bicubic', 'spline16', 'spline36', 'hanning', 'hamming', 'hermite', 'kaiser', 'quadric', 'catrom', 'gaussian', 'bessel', 'mitchell', 'sinc', 'lanczos']
+            percentage_intensity (None or number): If None it takes from CONF_DRAWING['percentage_intensity'], else uses this value
         """
 
         if reduce_matrix is False:
@@ -1435,8 +1488,6 @@ class Scalar_field_XZ(object):
             u_new = self.u[::reduce_matrix[0], ::reduce_matrix[1]]
             amplitude, intensity, phase = field_parameters(u_new, True)
 
-        # phase[intensity < 0.005 * (intensity.max())] = 0
-
         if z_scale == 'um':
             extension = [self.z[0], self.z[-1], self.x[0], self.x[-1]]
         elif z_scale == 'mm':
@@ -1444,7 +1495,8 @@ class Scalar_field_XZ(object):
                 self.z[0] / mm, self.z[-1] / mm, self.x[0], self.x[-1]
             ]
 
-        percentaje_intensity = params_drawing['percentaje_intensity']
+        if percentage_intensity is None:
+            percentage_intensity = percentage_intensity_config
 
         plt.figure()
 
@@ -1456,7 +1508,7 @@ class Scalar_field_XZ(object):
             I_drawing = normalize_draw(I_drawing, logarithm, normalize)
         elif kind == 'phase':
             phase = phase / degrees
-            phase[intensity < percentaje_intensity * (intensity.max())] = 0
+            phase[intensity < percentage_intensity * (intensity.max())] = 0
 
             I_drawing = phase
         elif kind == 'real':
@@ -1469,7 +1521,8 @@ class Scalar_field_XZ(object):
                         interpolation=interpolation,
                         aspect='auto',
                         origin='lower',
-                        extent=extension, **kwargs)
+                        extent=extension,
+                        **kwargs)
 
         if z_scale == 'um':
             plt.xlabel('z ($\mu m$)')
@@ -1480,13 +1533,13 @@ class Scalar_field_XZ(object):
 
         if colormap_kind in ('', [], None, True):
             if kind == 'intensity':
-                colormap_kind = self.params_drawing["color_intensity"]
+                colormap_kind = self.CONF_DRAWING["color_intensity"]
             if kind == 'amplitude':
-                colormap_kind = self.params_drawing["color_amplitude"]
+                colormap_kind = self.CONF_DRAWING["color_amplitude"]
             if kind == 'phase':
-                colormap_kind = self.params_drawing["color_phase"]
+                colormap_kind = self.CONF_DRAWING["color_phase"]
             if kind == 'real':
-                colormap_kind = self.params_drawing["color_real"]
+                colormap_kind = self.CONF_DRAWING["color_real"]
 
         if kind == 'intensity':
             climits = I_drawing.min(), I_drawing.max()
@@ -1500,7 +1553,7 @@ class Scalar_field_XZ(object):
         plt.axis(extension)
 
         if colorbar_kind not in (False, '', [], None):
-            plt.colorbar(orientation=colorbar_kind)
+            plt.colorbar(orientation=colorbar_kind, shrink=0.66)
 
         h1.set_cmap(colormap_kind)  # OrRd # Reds_r gist_heat
         plt.clim(climits)
@@ -1597,7 +1650,7 @@ class Scalar_field_XZ(object):
         h1.set_cmap(colormap_kind)  # flag OrRd # Reds_r gist_heat # gist_heat
 
         if colorbar_kind not in (False, '', None):
-            plt.colorbar(orientation=colorbar_kind)
+            plt.colorbar(orientation=colorbar_kind, shrink=0.66)
 
         if scale != '':
             plt.axis(scale)
@@ -1658,7 +1711,7 @@ class Scalar_field_XZ(object):
             numpy.array: profile
         """
 
-        imenor, value, distance = nearest(vector=self.x, number=x0)
+        imenor, _, _ = nearest(vector=self.x, number=x0)
 
         if kind == 'refraction_index':
             n_profile = np.abs(self.n[imenor, :])
@@ -1715,11 +1768,10 @@ class Scalar_field_XZ(object):
         Returns:
             numpy.array: profile
 
-        TODO:
-            Include interpolation
+        TODO: Include interpolation
         """
 
-        imenor, value, distance = nearest(vector=self.z, number=z0)
+        imenor, _, _ = nearest(vector=self.z, number=z0)
 
         if kind == 'refraction_index':
             n_profile = np.abs(self.n[:, imenor])
@@ -1742,7 +1794,6 @@ class Scalar_field_XZ(object):
                             dpi=300,
                             bbox_inches='tight',
                             pad_inches=0.1)
-                # ,dpi=600,bbox_inches='tight',pad_inches=0
 
         if kind == 'intensity':
             output = intensity
@@ -1771,22 +1822,25 @@ class Scalar_field_XZ(object):
             (x,z): positions of focus
         """
         intensity = np.abs(self.u)**2
-        # busca el máximo de una matrix bidimensional
+
         ix, iz = np.unravel_index(intensity.argmax(), intensity.shape)
         if verbose is True:
             print(("x = {:2.3f} um, z = {:2.3f} um".format(
                 self.x[ix], self.z[iz])))
         return self.x[ix], self.z[iz]
 
-    def beam_widths(self, kind='FWHM1D',
+    def beam_widths(self,
+                    kind='FWHM1D',
                     has_draw=[True, False],
-                    percentaje=0.5,
+                    percentage=0.5,
                     remove_background=None,
                     verbose=False):
         """Computes the beam width for all the distances z.
         Parameters:
             kind (str): kind of algorithm: 'sigma4', 'FWHM1D'
             has_draw (bool, bool): First for complete analysis, second for all FWHM2D computations
+            percentage (float): (0-1) percentage for the beam detection
+            remove_background=None,
             verbose (bool): prints info
 
         Returns:
@@ -1805,7 +1859,7 @@ class Scalar_field_XZ(object):
                 intensity = np.abs(field)**2
                 widths[i] = FWHM1D(self.x,
                                    intensity,
-                                   percentaje=percentaje,
+                                   percentage=percentage,
                                    remove_background=remove_background,
                                    has_draw=has_draw[1])
 
@@ -1816,70 +1870,73 @@ class Scalar_field_XZ(object):
             plt.ylabel("widths ($\mu$m)")
             plt.legend()
 
+        if verbose:
+            print("width = {:2.2f} um".format(widths))
+
         return widths, positions_center
 
-    def video_profiles(self,
-                       kind='intensity',
-                       kind_profile='transversal',
-                       step=1,
-                       wait=0.001,
-                       logarithm=False,
-                       normalize=False,
-                       filename='',
-                       verbose=False):
-        """Draws profiles in a video fashion
+    # def video_profiles(self,
+    #                    kind='intensity',
+    #                    kind_profile='transversal',
+    #                    step=1,
+    #                    wait=0.001,
+    #                    logarithm=False,
+    #                    normalize=False,
+    #                    filename='',
+    #                    verbose=False):
+    #     """Draws profiles in a video fashion
 
-        Parameters:
-            kind (str): 'intensity', 'amplitude', 'phase'
-            kind_profile (str): 'transversal', 'longitudinal'
-            step (list): number of frames shown (if 1 shows all, if 2 1/2, ..) for accelerating pruposes in video.
-            wait (float) : (in seconds) time for slow down the video
-            logarithm (bool): If True, intensity is scaled in logarithm
-            normalize (bool): If True, max(intensity)=1
-            filename: (str))  filename of video
-            verbose (bool): If True shows info
-        """
+    #     Parameters:
+    #         kind (str): 'intensity', 'amplitude', 'phase'
+    #         kind_profile (str): 'transversal', 'longitudinal'
+    #         step (list): number of frames shown (if 1 shows all, if 2 1/2, ..) for accelerating pruposes in video.
+    #         wait (float) : (in seconds) time for slow down the video
+    #         logarithm (bool): If True, intensity is scaled in logarithm
+    #         normalize (bool): If True, max(intensity)=1
+    #         filename: (str))  filename of video
+    #         verbose (bool): If True shows info
+    #     """
 
-        fig = plt.figure()
-        if kind_profile == 'transversal':
-            h1, = plt.plot(self.x, np.zeros_like(self.x), 'k', lw=2)
-            plt.xlim(self.x[0], self.x[-1])
-            plt.xlabel(r'$x (\mu m)$')
-        elif kind_profile == 'longitudinal':
-            h1, = plt.plot(self.z, np.zeros_like(self.z), 'k', lw=2)
-            plt.xlim(self.z[0], self.z[-1])
-            plt.xlabel(r'$z (\mu m)$')
+    #     fig = plt.figure()
+    #     if kind_profile == 'transversal':
+    #         h1, = plt.plot(self.x, np.zeros_like(self.x), 'k', lw=2)
+    #         plt.xlim(self.x[0], self.x[-1])
+    #         plt.xlabel(r'$x (\mu m)$')
+    #     elif kind_profile == 'longitudinal':
+    #         h1, = plt.plot(self.z, np.zeros_like(self.z), 'k', lw=2)
+    #         plt.xlim(self.z[0], self.z[-1])
+    #         plt.xlabel(r'$z (\mu m)$')
 
-        I_drawing = prepare_drawing(self.u, kind, logarithm, normalize)
+    #     I_drawing = prepare_drawing(self.u, kind, logarithm, normalize)
 
-        plt.ylim(I_drawing.min(), I_drawing.max())
+    #     plt.ylim(I_drawing.min(), I_drawing.max())
 
-        writer = prepare_video(fps=15, title='', artist='', comment='')
+    #     writer = prepare_video(fps=15, title='', artist='', comment='')
 
-        with writer.saving(fig, filename, 300):
-            if kind_profile == 'transversal':
-                for i in range(0, len(self.z), step):
-                    h1.set_ydata(I_drawing[:, i])
-                    plt.title("z={:6.2f}, i={}".format(round(self.z[i], 2), i))
-                    plt.draw()
-                    if filename == '':
-                        plt.pause(wait)
-                    else:
-                        if verbose:
-                            print(("{}/{}".format(i, len(self.z))))
-                        writer.grab_frame()
-            elif kind_profile == 'longitudinal':
-                for i in range(0, len(self.x), step):
-                    h1.set_ydata(I_drawing[i, :])
-                    plt.title("x={:6.2f}, i={}".format(round(self.x[i], 2), i))
-                    plt.draw()
-                    if filename == '':
-                        plt.pause(wait)
-                    else:
-                        if verbose:
-                            print(("{}/{}".format(i, len(self.z))))
-                        writer.grab_frame()
-        plt.close('')
+    #     with writer.saving(fig, filename, 300):
+    #         if kind_profile == 'transversal':
+    #             for i in range(0, len(self.z), step):
+    #                 h1.set_ydata(I_drawing[:, i])
+    #                 plt.title("z={:6.2f}, i={}".format(round(self.z[i], 2), i))
+    #                 plt.draw()
+    #                 if filename == '':
+    #                     plt.pause(wait)
+    #                 else:
+    #                     if verbose:
+    #                         print(("{}/{}".format(i, len(self.z))))
+    #                     writer.grab_frame()
+    #         elif kind_profile == 'longitudinal':
+    #             for i in range(0, len(self.x), step):
+    #                 h1.set_ydata(I_drawing[i, :])
+    #                 plt.title("x={:6.2f}, i={}".format(round(self.x[i], 2), i))
+    #                 plt.draw()
+    #                 if filename == '':
+    #                     plt.pause(wait)
+    #                 else:
+    #                     if verbose:
+    #                         print(("{}/{}".format(i, len(self.z))))
+    #                     writer.grab_frame()
+    #     plt.close('')
 
     def video(self,
               kind='intensity',
@@ -1972,7 +2029,7 @@ class Scalar_field_XZ(object):
         z_actual = self.z[0]
         x = self.x
         ix, iz = np.unravel_index(I_drawing.argmax(), I_drawing.shape)
-        # I_drawing_maxima = I_drawing[ix, iz]
+
         extension = [self.x[0], self.x[-1], I_drawing.min(), I_drawing.max()]
 
         imenor, value, distance = nearest(vector=self.z, number=z_actual)
@@ -1999,7 +2056,7 @@ def __update__(val):
     zz = zZ.val
     imenor, value, distance = nearest(vector=z, number=zz)
     I_drawing_profile = np.squeeze(I_drawing[:, imenor])
-    # lo siguiente normaliza linea a línea:
+
     I_drawing_profile = normalize_draw(I_drawing_profile, log1, norm1)
     l2a.set_ydata(I_drawing_profile)
     plt.draw()
