@@ -15,7 +15,7 @@ The main atributes are:
     * slit, double slit
     * two_levels, gray_scale
     * prism, biprism_fresnel, biprism_fresnel_nh
-    * lens, aspheric, fresnel_lens
+    * lens, lens_spherical, aspheric, fresnel_lens
     * roughness, dust, dust_different_sizes
     * sine_grating, ronchi_grating, binary_grating, blazed_grating
     * chriped_grating, chirped_grating_p, chirped_grating_q
@@ -88,9 +88,8 @@ class Scalar_mask_X(Scalar_field_X):
                            f1=0,
                            f2=0,
                            v_globals={},
-                           mask=True,
                            x0=0 * um,
-                           radius=100 * um):
+                           radius=0 * um):
         """Phase mask defined between two surfaces :math:`f_1` and :math:`f_2`: :math:`h(x,y)=f_2(x,y)-f_1(x,y)`, :math:`t(x)=mask(x)e^{i\,k\,(n-1)(f_{2}-f_{1})}`
 
         Parameters:
@@ -105,13 +104,12 @@ class Scalar_mask_X(Scalar_field_X):
 
         k = 2 * np.pi / self.wavelength
 
-        if mask is True:
+        if radius > 0:
             amplitude = Scalar_mask_X(self.x, self.wavelength)
             amplitude.slit(x0, radius)
             t = amplitude.u
         else:
-            t = np.ones_like(self.X)
-
+            t = 1
         v_locals = {'self': self, 'np': np, 'degrees': degrees}
 
         F2 = eval(f2, v_globals, v_locals)
@@ -124,8 +122,7 @@ class Scalar_mask_X(Scalar_field_X):
                         array1=None,
                         array2=None,
                         interp_kind='quadratic',
-                        mask=True,
-                        radius=100 * um,
+                        radius=0 * um,
                         x0=0 * um):
         """Phase mask defined between two surfaces defined by arrays: array1 and array2, :math:`t(x)=mask(x)e^{i\,k\,(n-1)(array2(x,z)-array1(x,z))}`
 
@@ -141,25 +138,23 @@ class Scalar_mask_X(Scalar_field_X):
 
         k = 2 * np.pi / self.wavelength
 
-        if mask is True:
+        if radius > 0:
             amplitude = Scalar_mask_X(self.x, self.wavelength)
             amplitude.slit(x0, radius)
             t = amplitude.u
         else:
-            t = np.ones_like(self.x)
+            t = 1
 
-        f1_interp = interp1d(
-            array1[:, 0],
-            array1[:, 1],
-            kind=interp_kind,
-            bounds_error=False,
-            fill_value=0)
-        f2_interp = interp1d(
-            array2[:, 0],
-            array2[:, 1],
-            kind=interp_kind,
-            bounds_error=False,
-            fill_value=0)  # interpolates all the range
+        f1_interp = interp1d(array1[:, 0],
+                             array1[:, 1],
+                             kind=interp_kind,
+                             bounds_error=False,
+                             fill_value=0)
+        f2_interp = interp1d(array2[:, 0],
+                             array2[:, 1],
+                             kind=interp_kind,
+                             bounds_error=False,
+                             fill_value=0)  # interpolates all the range
 
         F1 = f1_interp(self.x)
         F2 = f2_interp(self.x)
@@ -235,7 +230,7 @@ class Scalar_mask_X(Scalar_field_X):
 
         # Definicion de un primer level de unos
         self.u = level1 * np.ones(self.x.shape)
-        # Aquellos points cuyo mayor sea mayor que el value de corte, adquieren
+        # Aquellos points cuyo mayor sea mayor que el value de bin_level, adquieren
         # el value del level2
         self.u[self.x > x_edge] = level2
 
@@ -267,8 +262,6 @@ class Scalar_mask_X(Scalar_field_X):
             n (float): refraction_index
             anglex (float): angle of prism
 
-        TODO:
-            I think it is wrong: include refraction index
         """
 
         k = 2 * np.pi / self.wavelength
@@ -279,7 +272,7 @@ class Scalar_mask_X(Scalar_field_X):
         h = h - h.min()
         return h
 
-    def biprism_fresnel(self, angle, x0, radius, mask):
+    def biprism_fresnel(self, angle, x0, radius=0):
         """Fresnel biprism.
 
         Parameters:
@@ -304,7 +297,9 @@ class Scalar_mask_X(Scalar_field_X):
 
         t = np.ones_like(self.x)
 
-        if mask is True:
+        if radius == 0:
+            t = 1
+        else:
             ipasa = np.abs(self.x - x0) > radius
             t[ipasa] = 0.
             remove_phase_out = np.angle(u)
@@ -313,11 +308,7 @@ class Scalar_mask_X(Scalar_field_X):
 
         self.u = u * t
 
-    def biprism_fresnel_nh(self,
-                           x0,
-                           width,
-                           height,
-                           n):
+    def biprism_fresnel_nh(self, x0, width, height, n):
         """Fresnel biprism, uses height and refraction index.
 
         Parameters:
@@ -349,41 +340,65 @@ class Scalar_mask_X(Scalar_field_X):
         self.u = u * np.exp(1.j * k * (n - 1) * h)
         return h
 
-    def lens(self, x0, focal, radius, mask=True):
-        """Transparent lens.
+    def lens(self, x0, focal, radius=0):
+        """Paraxial lens.
 
         Parameters:
             x0 (float): center of lens
             focal (float): focal length of lens
-            mask (bool): if True, mask with size radius
-            radius (float): radius of lens mask
         """
 
         k = 2 * np.pi / self.wavelength
 
         # Definicion de la amplitude y la phase
-        if mask is True:
-            # amplitude = Scalar_mask_X(self.x, self.wavelength)
-            # amplitude.slit(x0, 2 * radius)
-            # t = amplitude.u
-            t = np.zeros_like(self.x, dtype=np.int)
+        if radius == 0:
+            t = 1
+
+        else:
+            t = np.zeros_like(self.x)
             ix = (self.x < x0 + radius) & (self.x > x0 - radius)
             t[ix] = 1
-        else:
-            t = np.ones_like(self.x, dtype=np.int)
 
         h = (self.x - x0)**2 / (2 * focal)
         self.u = t * np.exp(-1.j * k * h)
-        self.u[t == 0] = 0
 
         h = h - h.min()
         h = h / h.max()
-        return t * h
+        return h
 
-    def aspheric(self, x0, c, k, a, n0, n1, radius, mask=True):
-        """asferic surface.
+    def lens_spherical(self, x0, radius, focal, refraction_index=1.5):
+        """Spherical lens, without paraxial approximation. The focal distance and the refraction index are used for the definition.
+        When the refraction index decreases, the radius of curvature decrases and less paraxial.
 
-        $z = \frac{c r^2}{1+\sqrt{1-(1+k) c^2 r^2 }}+\sum{a_i r^{2i}}$
+        Parameters:
+            r0 (float, float): (x0,y0) - center of lens
+            radius (float, float) or (float): radius of lens mask
+            focal (float, float) or (float): focal length of lens
+            refraction index (float): refraction index of the lens
+
+        """
+
+        k = 2 * np.pi / self.wavelength
+
+        R = (refraction_index - self.n_background) * focal
+
+        if radius == 0:
+            t = 1
+        else:
+            t = np.zeros_like(self.x, dtype=int)
+            ix = (self.x < x0 + radius) & (self.x > x0 - radius)
+            t[ix] = 1
+
+        h = (np.sqrt(R**2 - self.x**2) - R)
+
+        h[(R**2 - self.x**2) < 0] = 0
+        self.u = t * np.exp(1j * k * (refraction_index - 1) * h)
+        self.u[t == 0] = 0
+
+        return self
+
+    def aspheric(self, x0, c, k, a, n0, n1, radius):
+        """Asferic surface. $z = \frac{c r^2}{1+\sqrt{1-(1+k) c^2 r^2 }}+\sum{a_i r^{2i}}$
 
         Parameters:
             x0 (float): position of center
@@ -394,13 +409,12 @@ class Scalar_mask_X(Scalar_field_X):
             n1 (float): refraction index of second medium
             radius (float): radius of aspheric surface
 
-
-        Conic Constant    Surface Type
-        k = 0             spherical
-        k = -1            Paraboloid
-        k < -1            Hyperboloid
-        -1 < k < 0        Ellipsoid
-        k > 0             Oblate eliposid
+            Conic Constant    Surface Type
+            k = 0             spherical
+            k = -1            Paraboloid
+            k < -1            Hyperboloid
+            -1 < k < 0        Ellipsoid
+            k > 0             Oblate eliposid
 
         References:
             https://www.edmundoptics.com/knowledge-center/application-notes/optics/all-about-aspheric-lenses/
@@ -412,16 +426,16 @@ class Scalar_mask_X(Scalar_field_X):
         t2 = 0
         if a is not None:
             for i, ai in enumerate(a):
-                t2 = t2 + ai * s2 ** (2 + i)
+                t2 = t2 + ai * s2**(2 + i)
 
         t = t1 + t2
 
-        if mask is True:
+        if radius > 0:
             m1 = np.zeros_like(self.x, dtype=int)
             ix = (self.x < x0 + radius) & (self.x > x0 - radius)
             m1[ix] = 1
         else:
-            m1 = np.ones_like(self.x, dtype=int)
+            m1 = 1
 
         self.u = m1 * np.exp(1j * 2 * np.pi * (n1 - n0) * t / self.wavelength)
         self.u[m1 == 0] = 0
@@ -433,7 +447,6 @@ class Scalar_mask_X(Scalar_field_X):
                      kind='amplitude',
                      binary=True,
                      phase=np.pi,
-                     mask=True,
                      radius=100 * um):
         """Fresnel lens. Amplitude phase, continuous or binary.
 
@@ -453,21 +466,23 @@ class Scalar_mask_X(Scalar_field_X):
         k = 2 * np.pi / self.wavelength
 
         # Definicion de la amplitude y la phase
-        if mask is True:
+        if radius > 0:
 
             t1 = np.zeros_like(self.x)
             ix = (self.x < x0 + radius) & (self.x > x0 - radius)
             t1[ix] = 1
         else:
-            t1 = np.ones_like(self.x)
+            t1 = 1
 
         if kind == 'amplitude' and binary is True:
-            u_fresnel = np.cos(k * ((self.x - x0)**2 / (2 * focal)))
+            # u_fresnel = np.cos(k * ((self.x - x0)**2 / (2 * focal)))
+            u_fresnel = np.sin(k * ((self.x - x0)**2 / (2 * focal)))
             u_fresnel[u_fresnel > 0] = 1
             u_fresnel[u_fresnel <= 0] = 0
 
         elif kind == 'phase' and binary is True:
-            u_fresnel = np.cos(k * ((self.x - x0)**2 / (2 * focal)))
+            # u_fresnel = np.cos(k * ((self.x - x0)**2 / (2 * focal)))
+            u_fresnel = np.sin(k * ((self.x - x0)**2 / (2 * focal)))
             u_fresnel[u_fresnel > 0] = 1
             u_fresnel[u_fresnel <= 0] = 0
             u_fresnel = np.exp(1j * u_fresnel * phase)
@@ -478,7 +493,8 @@ class Scalar_mask_X(Scalar_field_X):
             u_fresnel = np.exp(1j * fase * phase)
 
         elif kind == 'amplitude' and binary is False:
-            u_fresnel = (1 + np.cos(k * ((self.x - x0)**2 / (2 * focal)))) / 2
+            # u_fresnel = (1 + np.cos(k * ((self.x - x0)**2 / (2 * focal)))) / 2
+            u_fresnel = (1 + np.sin(k * ((self.x - x0)**2 / (2 * focal)))) / 2
 
         h = u_fresnel
         h = h - h.min()
@@ -509,24 +525,24 @@ class Scalar_mask_X(Scalar_field_X):
         self.u = u
         return h_corr
 
-    def dust_different_sizes(self, percentaje, size, std=0):
+    def dust_different_sizes(self, percentage, size, std=0):
         """Mask with dust particles of different sizes.
 
         Parameters:
-            percentaje (float): percentaje of area afected by noise
+            percentage (float): percentage of area afected by noise
             size (float): mean size of dust
             std (float): std for size of dust
 
         Returns:
             numpy.array: positions - positions of dust
             numpy.array: sizes - size of dust
-            float: percentaje_real - real percentaje of dust
+            float: percentage_real - real percentage of dust
         """
 
         total_length = self.x[-1] - self.x[0]
-        num_particles = int(percentaje * total_length / size)
-        if percentaje > 0.5:
-            num_particles = int(num_particles * (1 + np.sqrt(percentaje)))
+        num_particles = int(percentage * total_length / size)
+        if percentage > 0.5:
+            num_particles = int(num_particles * (1 + np.sqrt(percentage)))
         sizes = size + std * np.random.randn(num_particles)
         sizes[sizes < 0] = size
         positions = self.x[0] + total_length * np.random.rand(num_particles)
@@ -545,30 +561,30 @@ class Scalar_mask_X(Scalar_field_X):
         # dust.u[dust.u < 1] = value
         self.u = dust.u
         # can be used to increase dust_particles, when there is overlapping
-        percentaje_real = 1 - self.u.sum() / len(self.x)
+        percentage_real = 1 - self.u.sum() / len(self.x)
 
-        return positions, sizes, percentaje_real
+        return positions, sizes, percentage_real
 
-    def dust(self, percentaje, size=0):
+    def dust(self, percentage, size=0):
         """ Mask with dust particles of equal sizes.
 
         Parameters:
-            percentaje (float): percentaje of area afected by noise
+            percentage (float): percentage of area afected by noise
             size (float): size of dust
             value (float): value included when there is noise
 
         Returns:
             numpy.array: positions - positions of dust
             numpy.array: sizes - size of dust
-            float: percentaje_real - real percentaje of dust
+            float: percentage_real - real percentage of dust
         """
 
         total_length = self.x[-1] - self.x[0]
         dx = self.x[1] - self.x[0]
         i_center = int(len(self.x) / 2)
-        num_particles = int(percentaje * total_length / size)
-        if percentaje > 0.5:
-            num_particles = int(num_particles * (1 + np.sqrt(percentaje)))
+        num_particles = int(percentage * total_length / size)
+        if percentage > 0.5:
+            num_particles = int(num_particles * (1 + np.sqrt(percentage)))
         # habria que quitar algo por los solapamientos
         positions = self.x[0] + total_length * np.random.rand(num_particles)
 
@@ -585,9 +601,9 @@ class Scalar_mask_X(Scalar_field_X):
 
         self.u = 1 - dust
 
-        percentaje_real = self.u.sum() / len(self.x)
+        percentage_real = self.u.sum() / len(self.x)
 
-        return positions, percentaje_real
+        return positions, percentage_real
 
     def sine_grating(self, x0, period, amp_min=0, amp_max=1):
         """Sinusoidal grating
@@ -599,8 +615,9 @@ class Scalar_mask_X(Scalar_field_X):
             amp_max (float): maximum amplitude
         """
         # Definicion de la sinusoidal
-        self.u = amp_min + (amp_max - amp_min) * (
-            1 + np.cos(2 * np.pi * (self.x - x0) / period)) / 2
+        self.u = amp_min + (amp_max -
+                            amp_min) * (1 + np.cos(2 * np.pi *
+                                                   (self.x - x0) / period)) / 2
 
         return self.u
 
@@ -621,13 +638,7 @@ class Scalar_mask_X(Scalar_field_X):
         self.u = t.u
         return t.u
 
-    def binary_grating(self,
-                       x0,
-                       period,
-                       fill_factor,
-                       amin,
-                       amax,
-                       phase):
+    def binary_grating(self, x0, period, fill_factor, amin, amax, phase):
         """binary grating amplitude and/or phase
 
         Parameters:
@@ -645,7 +656,13 @@ class Scalar_mask_X(Scalar_field_X):
         self.u = self.u * np.exp(1j * phase * t.u)
         return t.u
 
-    def blazed_grating(self, x0, period, height, n, ):
+    def blazed_grating(
+        self,
+        x0,
+        period,
+        height,
+        n,
+    ):
         """Phase, blazed grating. The phase shift is determined by heigth and refraction index.
 
         Parameters:
@@ -747,10 +764,10 @@ class Scalar_mask_X(Scalar_field_X):
 
         if kind == 'amplitude_binary' or kind == 'phase_binary':
             levels = [0, 1]
-            corte = 0.5
+            bin_level = 0.5
             t_binaria = np.zeros_like(t, dtype='float')
-            t_binaria[t <= corte] = levels[0]
-            t_binaria[t > corte] = levels[1]
+            t_binaria[t <= bin_level] = levels[0]
+            t_binaria[t > bin_level] = levels[1]
             t = t_binaria
 
         if kind == 'amplitude':
@@ -842,10 +859,10 @@ class Scalar_mask_X(Scalar_field_X):
 
         if kind == 'amplitude_binary' or kind == 'phase_binary':
             levels = [0, 1]
-            corte = 0.5
+            bin_level = 0.5
             t_binaria = np.zeros_like(t, dtype='float')
-            t_binaria[t <= corte] = levels[0]
-            t_binaria[t > corte] = levels[1]
+            t_binaria[t <= bin_level] = levels[0]
+            t_binaria[t > bin_level] = levels[1]
             t = t_binaria
 
         if kind == 'amplitude':
@@ -896,17 +913,17 @@ class Scalar_mask_X(Scalar_field_X):
 
         period = eval(p_x)
         q_x = 2 * np.pi / period
-        t = amp_min + (amp_max - amp_min) * (
-            1 + np.cos(q_x * (self.x - delta_x))) / 2
+        t = amp_min + (amp_max -
+                       amp_min) * (1 + np.cos(q_x * (self.x - delta_x))) / 2
         # plt.figure()
         # plt.plot(t)
 
         if kind == 'amplitude_binary' or kind == 'phase_binary':
             levels = [0, 1]
-            corte = 0.5
+            bin_level = 0.5
             t_binaria = np.zeros_like(t, dtype='float')
-            t_binaria[t <= corte] = levels[0]
-            t_binaria[t > corte] = levels[1]
+            t_binaria[t <= bin_level] = levels[0]
+            t_binaria[t > bin_level] = levels[1]
             t = t_binaria
 
         if kind == 'amplitude':
@@ -921,7 +938,10 @@ class Scalar_mask_X(Scalar_field_X):
 
         return t
 
-    def binary_code_positions(self, x_transitions, start='down', has_draw=True):
+    def binary_code_positions(self,
+                              x_transitions,
+                              start='down',
+                              has_draw=True):
         """
         Genenerates a binary code, using the positions given in x_transitions
 
@@ -979,8 +999,8 @@ class Scalar_mask_X(Scalar_field_X):
         if kind == 'abs_fag':
             i0_ones = np.ones_like(code)
             i0_zeros = np.zeros_like(code)
-            code = np.vstack((i0_zeros, i0_ones, code, i0_ones)).reshape((-1, ),
-                                                                         order='F')
+            code = np.vstack((i0_zeros, i0_ones, code, i0_ones)).reshape(
+                (-1, ), order='F')
             bit_width = bit_width / 4
 
         t = Scalar_mask_X(self.x, self.wavelength)
