@@ -1,7 +1,6 @@
-# !/usr/bin/env python3
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-"""
-This module generates Scalar_mask_XZ class for definingn masks. Its parent is Scalar_field_XZ.
+"""Generates Scalar_mask_XZ class for definingn masks. Its parent is Scalar_field_XZ.
 
 The main atributes are:
     * self.x - x positions of the field
@@ -73,9 +72,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         z: numpy array with z locations
         wavelength: wavelength of light
         n_backgraound: refraction index of background
-        info: text to describe the instance of the class
-        """
-        # print("init de Scalar_mask_XZ")
+        info: text to describe the instance of the class"""
         super(self.__class__, self).__init__(x, z, wavelength, n_background,
                                              info)
 
@@ -107,10 +104,10 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
                 refraction_index = eval(tmp_refraction_index, v_globals,
                                         v_locals)
-                # print("aqui: {}".format(refraction_index))
-
-            self.n[:, index] = refraction_index * (1 - t.u)
-            self.n[:, index] = self.n[:, index] + self.n_background * t.u
+            self.n = self.n.astype(complex)
+            self.n[:, index] = (refraction_index * (1 - t.u))
+            self.n[:, index] = (self.n[:, index] + self.n_background * t.u)
+            # self.n = refraction_index
 
     def mask_from_function(self,
                            r0,
@@ -161,7 +158,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Parameters:
             r0 (float, float): location of the mask
-            refractdion_index (float, str): can be a number or a function n(x,z)
+            refraction_index (float, str): can be a number or a function n(x,z)
             array1 (numpy.array): array (x,z) that delimits the first surface
             array2 (numpy.array): array (x,z) that delimits the second surface
             x_sides (float, float): limiting upper and lower values in x,
@@ -172,21 +169,19 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         x_c, z_c = r0
 
-        f1_interp = interp1d(
-            array1[:, 0] + x_c,
-            array1[:, 1] + z_c,
-            kind=interp_kind,
-            bounds_error=False,
-            fill_value=array1[0, 1] + z_c,
-            assume_sorted=True)
+        f1_interp = interp1d(array1[:, 0] + x_c,
+                             array1[:, 1] + z_c,
+                             kind=interp_kind,
+                             bounds_error=False,
+                             fill_value=array1[0, 1] + z_c,
+                             assume_sorted=True)
 
-        f2_interp = interp1d(
-            array2[:, 0] + x_c,
-            array2[:, 1] + z_c,
-            kind=interp_kind,
-            bounds_error=False,
-            fill_value=array2[0, 1] + z_c,
-            assume_sorted=True)
+        f2_interp = interp1d(array2[:, 0] + x_c,
+                             array2[:, 1] + z_c,
+                             kind=interp_kind,
+                             bounds_error=False,
+                             fill_value=array2[0, 1] + z_c,
+                             assume_sorted=True)
 
         F1 = f1_interp(self.x)
         F2 = f2_interp(self.x)
@@ -246,21 +241,19 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         x0, z0 = r0
 
-        f1_interp = interp1d(
-            array1[:, 0] + x0,
-            array1[:, 1] + z0,
-            kind=interp_kind,
-            bounds_error=False,
-            fill_value=array1[0, 1] + z0,
-            assume_sorted=True)
+        f1_interp = interp1d(array1[:, 0] + x0,
+                             array1[:, 1] + z0,
+                             kind=interp_kind,
+                             bounds_error=False,
+                             fill_value=array1[0, 1] + z0,
+                             assume_sorted=True)
 
-        f2_interp = interp1d(
-            array2[:, 0] + x0,
-            array2[:, 1] + z0,
-            kind=interp_kind,
-            bounds_error=False,
-            fill_value=array2[0, 1] + z0,
-            assume_sorted=True)
+        f2_interp = interp1d(array2[:, 0] + x0,
+                             array2[:, 1] + z0,
+                             kind=interp_kind,
+                             bounds_error=False,
+                             fill_value=array2[0, 1] + z0,
+                             assume_sorted=True)
 
         F1 = f1_interp(self.x)
         F2 = f2_interp(self.x)
@@ -427,34 +420,91 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         perfil_previo = self.borders
         self.clear_refraction_index()
-        self.mask_from_array(
-            r0=(0 * um, 0 * um),
-            refraction_index=refraction_index,
-            array1=fx1_n,
-            array2=fx2_n,
-            x_sides=x_sides,
-            angle=0 * degrees,
-            interp_kind='linear')
+        self.mask_from_array(r0=(0 * um, 0 * um),
+                             refraction_index=refraction_index,
+                             array1=fx1_n,
+                             array2=fx2_n,
+                             x_sides=x_sides,
+                             angle=0 * degrees,
+                             interp_kind='linear')
 
         self.surface_detection()  # bordes nuevos
         perfil_nuevo = self.borders
 
         return perfil_previo, perfil_nuevo
 
-    def discretize_refraction_index(self, n_layers):
+    def discretize_refraction_index(self,
+                                    num_layers=None,
+                                    n_layers=None,
+                                    new_field=False):
         """Takes a refraction index an discretize it according refraction indexes.
 
-        Parameters:
-            n_layers (np.array): array with refraction indexes to discretize
+        Args:
+            num_layers ((int,int), optional): number of layers (for real and imaginary parts), without counting background. Defaults to None.
+                By default, both parameters are None, but one of then must be filled. If both are present, num_layers is considered
+            n_layers (np.array, optional): array with refraction indexes to discretize. Defaults to None.
+            new_field (bool): If True, it generates a new field.
+
+        Returns:
+            (np.array): refraction indexes selected.
         """
-        n = deepcopy(self.n)
-        for i, n_layer in enumerate(n_layers[:-1]):
-            i_capa = np.bitwise_and(self.n >= n_layers[i],
-                                    self.n <= n_layers[i + 1])
-            n_central = (n_layers[i] + n_layers[i + 1]) / 2
-            n[i_capa] = n_central
-        self.n = n
-        return n
+
+        def _discretize_(refraction_index, n_layers):
+            n_new = np.zeros_like(refraction_index, dtype=float)
+
+            i_n, _, _ = nearest2(n_layers, refraction_index)
+            i_n = i_n.reshape(refraction_index.shape)
+
+            for i, n in enumerate(n_layers):
+                n_new[i_n == i] = n_layers[i]
+
+            return n_new
+
+        if num_layers is not None:
+            if isinstance(num_layers, int):
+                num_layers = (num_layers, 1)
+
+        n_real = np.around(self.n.real, 4)
+        kappa = np.around(self.n.imag, 4)
+
+        if num_layers[0] is not None:
+            if num_layers[0] > 1:
+                repeated_values = np.unique(n_real)
+                repeated_values = np.delete(
+                    repeated_values,
+                    np.where(repeated_values == self.n_background))
+
+                n_min, n_max = repeated_values.min(), repeated_values.max()
+                n_layers = np.linspace(n_min, n_max, num_layers[0])
+                n_layers = np.append(n_layers, self.n_background)
+                n_layers = np.unique(n_layers)
+                n_new = _discretize_(n_real, n_layers)
+            else:
+                n_new = n_real
+        else:
+            n_new = n_real
+
+        if num_layers[1] is not None:
+            if num_layers[1] > 1:
+                repeated_values = np.unique(kappa)
+
+                k_min, k_max = repeated_values.min(), repeated_values.max()
+                k_layers = np.linspace(k_min, k_max, num_layers[1])
+                k_layers = np.unique(k_layers)
+                k_new = _discretize_(kappa, k_layers)
+            else:
+                k_new = np.zeros_like(kappa)
+                k_new[kappa > kappa.max() / 2] = kappa.max()
+        else:
+            k_new = kappa
+
+        if new_field is True:
+            t_new = self.duplicate()
+            t_new.u = np.zeros_like(t_new.u)
+            t_new.n = n_new + 1j * k_new
+            return t_new
+        else:
+            self.n = n_new + 1j * k_new
 
     def image(self, filename, n_max, n_min, angle=0, invert=False):
         """Converts an image file in an xz-refraction index matrix.
@@ -468,8 +518,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             angle (float): angle to rotate the image in radians
             invert (bool): if True the image is inverted
 
-        TODO:
-            Now it is only possible that image size is equal to XZ, change using interpolation
+        TODO: Now it is only possible that image size is equal to XZ, change using interpolation
             Rotation position
         """
 
@@ -525,7 +574,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         return self
 
     def semi_plane(self, r0, refraction_index, angle=0, rotation_point=None):
-        """Inserts a semi-sphere in background (x>x0). If it is something else previous, it is removed.
+        """Inserts a semi-sphere in background (x>x0). If something else previous, it is removed.
 
         Parameters:
             r0=(x0,z0) (float,float): Location of the same plane.
@@ -542,8 +591,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond1]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
         return ipasa
 
     def layer(self, r0, depth, refraction_index, angle, rotation_point=None):
@@ -566,8 +618,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond1, cond2]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
         return ipasa
 
     def rectangle(self,
@@ -615,8 +670,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond1, cond2, cond3, cond4]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={'np': np})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={'np': np})
 
         return ipasa
 
@@ -654,13 +712,19 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs1 = [cond1, cond2]
 
-        ipasa_slit = self.object_by_surfaces(
-            r0, refraction_index, Fs1, angle, v_globals={})
+        ipasa_slit = self.object_by_surfaces(r0,
+                                             refraction_index,
+                                             Fs1,
+                                             angle,
+                                             v_globals={})
 
         Fs2 = [cond1, cond2, cond3, cond4]
         if refraction_index_center not in ('', [], 0):
-            ipasa = self.object_by_surfaces(
-                r0, refraction_index_center, Fs2, angle, v_globals={})
+            ipasa = self.object_by_surfaces(r0,
+                                            refraction_index_center,
+                                            Fs2,
+                                            angle,
+                                            v_globals={})
         elif refraction_index_center in ('', [], 0):
             ipasa = self.object_by_surfaces(r0, 1, Fs2, angle, v_globals={})
             self.n[ipasa] = n_back[ipasa]
@@ -696,8 +760,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
         return ipasa
 
     def semi_sphere(self,
@@ -731,8 +798,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond1, cond2]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
         return ipasa
 
     def lens_plane_convergent(self,
@@ -748,9 +818,8 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Parameters:
             r0 (float, float): (x0,z0) position of the center of lens, for example (0 * um, 20 * um)
-              for plane-convergent z0 is the location of the plane
-              for convergent-plane (angle =180*degrees) the thickness has to be
-                  added to z0
+                for plane-convergent z0 is the location of the plane
+                for convergent-plane (angle =180*degrees) the thickness has to be added to z0
             aperture (float): aperture of the lens. If it is 0, then it is not applied
             radius (float): radius of the curved surface
             thickness (float): thickness at the center of the lens
@@ -788,18 +857,20 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             x0, z_center_lens, radius)
         Fs = [cond_aperture1, cond_aperture2, cond_plane, cond_radius]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
 
         if mask_depth > 0:
-            self.slit(
-                r0=r0,
-                aperture=aperture,
-                depth=mask_depth,
-                refraction_index=mask_refraction_index,
-                refraction_index_center='',
-                angle=angle,
-                rotation_point=rotation_point)
+            self.slit(r0=r0,
+                      aperture=aperture,
+                      depth=mask_depth,
+                      refraction_index=mask_refraction_index,
+                      refraction_index_center='',
+                      angle=angle,
+                      rotation_point=rotation_point)
         focus = radius / (refraction_index - 1)
         return focus, ipasa
 
@@ -859,19 +930,23 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond_aperture1, cond_aperture2, cond_radius1, cond_radius2]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
 
         if mask_depth > 0:
-            self.slit(
-                r0=r0,
-                aperture=aperture,
-                depth=mask_depth,
-                refraction_index=mask_refraction_index,
-                refraction_index_center='',
-                angle=angle)
+            self.slit(r0=r0,
+                      aperture=aperture,
+                      depth=mask_depth,
+                      refraction_index=mask_refraction_index,
+                      refraction_index_center='',
+                      angle=angle)
+
         focus_1 = (refraction_index - 1) * (
-            1 / radius1 - 1 / radius2) - thickness / (radius1 * radius2)
+            (1 / radius1 - 1 / radius2) - (refraction_index - 1) * thickness /
+            (refraction_index * radius1 * radius2))
         return 1 / focus_1, ipasa
 
     def lens_plane_divergent(self,
@@ -924,18 +999,20 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             cond_aperture1, cond_aperture2, cond_plane, cond_radius, cond_right
         ]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
 
         if mask_depth > 0:
-            self.slit(
-                r0=r0,
-                aperture=aperture,
-                depth=mask_depth,
-                refraction_index=mask_refraction_index,
-                refraction_index_center='',
-                angle=angle,
-                rotation_point=rotation_point)
+            self.slit(r0=r0,
+                      aperture=aperture,
+                      depth=mask_depth,
+                      refraction_index=mask_refraction_index,
+                      refraction_index_center='',
+                      angle=angle,
+                      rotation_point=rotation_point)
         focus = radius / (refraction_index - 1)
         return focus, ipasa
 
@@ -997,20 +1074,23 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             cond_right, cond_left
         ]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
 
         if mask_depth > 0:
-            self.slit(
-                r0=r0,
-                aperture=aperture,
-                depth=mask_depth,
-                refraction_index=mask_refraction_index,
-                refraction_index_center='',
-                angle=angle,
-                rotation_point=rotation_point)
+            self.slit(r0=r0,
+                      aperture=aperture,
+                      depth=mask_depth,
+                      refraction_index=mask_refraction_index,
+                      refraction_index_center='',
+                      angle=angle,
+                      rotation_point=rotation_point)
         focus_1 = (refraction_index - 1) * (
-            1 / radius1 - 1 / radius2) - thickness / (radius1 * radius2)
+            (1 / radius1 - 1 / radius2) - (refraction_index - 1) * thickness /
+            (refraction_index * radius1 * radius2))
         return 1 / focus_1, ipasa
 
     def aspheric_surface_z(self, r0, refraction_index, cx, Qx, a2, a3, a4,
@@ -1042,8 +1122,14 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         else:
             print("possible error in aspheric")
 
-        params = dict(
-            x0=x0, z0=z0, cx=cx, Qx=Qx, a2=a2, a3=a3, a4=a4, sign=sign)
+        params = dict(x0=x0,
+                      z0=z0,
+                      cx=cx,
+                      Qx=Qx,
+                      a2=a2,
+                      a3=a3,
+                      a4=a4,
+                      sign=sign)
 
         cond = "Zrot{sign}{z0}+{cx}*(Xrot-{x0})**2/(1+np.sqrt(1-(1+{Qx})*{cx}**2*(Xrot-{x0})**2+{a2}*(Xrot-{x0})**4+{a3}*(Xrot-{x0})**6)+{a4}*(Xrot-{x0})**8)".format(
             **params)
@@ -1051,8 +1137,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         Fs = [cond]
         v_globals = {'self': self, 'np': np, 'degrees': degrees}
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals=v_globals)
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals=v_globals)
         return ipasa
 
     def aspheric_lens(self,
@@ -1102,22 +1191,21 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         else:
             sign2 = '>'
 
-        params = dict(
-            cx1=cx1,
-            Qx1=Qx1,
-            cx2=cx2,
-            Qx2=Qx2,
-            x0=x0,
-            a21=a21,
-            a22=a22,
-            a31=a31,
-            a32=a32,
-            a41=a41,
-            a42=a42,
-            d1=z0,
-            d2=z0 + depth,
-            sign1=sign1,
-            sign2=sign2)
+        params = dict(cx1=cx1,
+                      Qx1=Qx1,
+                      cx2=cx2,
+                      Qx2=Qx2,
+                      x0=x0,
+                      a21=a21,
+                      a22=a22,
+                      a31=a31,
+                      a32=a32,
+                      a41=a41,
+                      a42=a42,
+                      d1=z0,
+                      d2=z0 + depth,
+                      sign1=sign1,
+                      sign2=sign2)
 
         cond1 = "Zrot{sign1}{d1}+{cx1}*(Xrot-{x0})**2/(1+np.sqrt(1-(1+{Qx1})*{cx1}**2*(Xrot-{x0})**2+{a21}*(Xrot-{x0})**4+{a31}*(Xrot-{x0})**6)+{a41}*(Xrot-{x0})**8)".format(
             **params)
@@ -1134,8 +1222,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         Fs = [cond1, cond2, cond3, cond4, cond5, cond6]
         v_globals = {'self': self, 'np': np, 'degrees': degrees}
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals=v_globals)
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals=v_globals)
 
         return ipasa, Fs
 
@@ -1166,8 +1257,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         cond3 = "(Xrot-{})<{}*(Zrot-{})".format(x0, np.tan(angle_wedge), z0)
         Fs = [cond1, cond2, cond3]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
         return ipasa
 
     def prism(self,
@@ -1200,8 +1294,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond1, cond2, cond3]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
         return ipasa
 
     def biprism(self, r0, length, height, refraction_index, angle=0):
@@ -1237,8 +1334,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond1, cond2, cond3]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals={})
         return ipasa
 
     def ronchi_grating(self, r0, period, fill_factor, length, height, Dx,
@@ -1255,7 +1355,7 @@ class Scalar_mask_XZ(Scalar_field_XZ):
             Dx (float): displacement of grating with respect x=0
             refraction_index (float, str): refraction index , for example: 1.5 + 1.0j
             heigth_substrate (float): height of the substrate
-            refraction_index_substrate (float, str): refraction index of substrate , for example: 1.5 + 1.0j
+            refraction_index_substrate (float, str): refraction index of substrate,  1.5 + 1.0j
             angle (float): angle of rotation of the semi-plane, in radians
         """
 
@@ -1266,23 +1366,21 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         t0 = Scalar_mask_X(x=self.x, wavelength=self.wavelength)
         t0.ronchi_grating(x0=Dx, period=period, fill_factor=fill_factor)
 
-        self.extrude_mask(
-            t=t0,
-            z0=z0 + heigth_substrate / 2,
-            z1=z0 + heigth_substrate / 2 + height,
-            refraction_index=refraction_index,
-            angle=angle)
+        self.extrude_mask(t=t0,
+                          z0=z0 + heigth_substrate / 2,
+                          z1=z0 + heigth_substrate / 2 + height,
+                          refraction_index=refraction_index,
+                          angle=angle)
 
         if heigth_substrate > 0:
             self.rectangle(r0, (length, heigth_substrate),
                            refraction_index_substrate, angle)
-        self.slit(
-            r0=(x0, z0 + heigth_substrate / 2),
-            aperture=length,
-            depth=height,
-            refraction_index=self.n_background,
-            refraction_index_center='',
-            angle=angle)
+        self.slit(r0=(x0, z0 + heigth_substrate / 2),
+                  aperture=length,
+                  depth=height,
+                  refraction_index=self.n_background,
+                  refraction_index_center='',
+                  angle=angle)
 
     def sine_grating(self,
                      period,
@@ -1344,8 +1442,11 @@ class Scalar_mask_XZ(Scalar_field_XZ):
         cond4 = "Zrot>{}".format(z0)
         Fs = [cond1, cond2, cond3, cond4]
         v_globals = {'self': self, 'np': np, 'degrees': degrees, 'um': um}
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, angle, v_globals=v_globals)
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        angle,
+                                        v_globals=v_globals)
         return ipasa
 
     def rough_sheet(self,
@@ -1401,14 +1502,19 @@ class Scalar_mask_XZ(Scalar_field_XZ):
 
         Fs = [cond1, cond2, cond3]
 
-        ipasa = self.object_by_surfaces(
-            rotation_point, refraction_index, Fs, 0, v_globals={})
+        ipasa = self.object_by_surfaces(rotation_point,
+                                        refraction_index,
+                                        Fs,
+                                        0,
+                                        v_globals={})
 
         i_z, _, _ = nearest2(self.z, z0 + sizez - fx)
         i_final = len(self.z)
         for i in range(len(self.x)):
             self.n[i, i_z[i]:i_final] = n_back[i, i_z[i]:i_final]
 
-        self.rotate_field(
-            angle, rotation_point, n_background=self.n_background)
+        if angle != 0:
+            self.rotate_field(angle,
+                              rotation_point,
+                              n_background=self.n_background)
         return ipasa
