@@ -68,7 +68,11 @@ class Scalar_source_XY(Scalar_field_XY):
         self.type = 'Scalar_source_XY'
 
     def plane_wave(self, A=1, theta=0 * degrees, phi=0 * degrees, z0=0 * um):
-        """Plane wave. self.u = A * exp(1.j * k * (self.x * sin(theta) + z0 * cos(theta)))
+        """Plane wave. self.u = A * exp(1.j * k *
+                         (self.X * sin(theta) * cos(phi) +
+                          self.Y * sin(theta) * sin(phi) + z0 * cos(theta)))
+        
+        According to https://en.wikipedia.org/wiki/Spherical_coordinate_system: physics (ISO 80000-2:2019 convention)
 
         Parameters:
             A (float): maximum amplitude
@@ -78,13 +82,15 @@ class Scalar_source_XY(Scalar_field_XY):
         """
         k = 2 * pi / self.wavelength
         self.u = A * exp(1.j * k *
-                         (self.X * sin(theta) * sin(phi) +
-                          self.Y * cos(theta) * sin(phi)) + z0 * cos(phi))
+                         (self.X * sin(theta) * cos(phi) +
+                          self.Y * sin(theta) * sin(phi) + z0 * cos(theta)))
 
     def gauss_beam(self,
                    r0,
                    w0,
-                   z0=0 * um,
+                   z0,
+                   alpha=0 * degrees,
+                   beta=0 * degrees,
                    A=1,
                    theta=0. * degrees,
                    phi=0 * degrees):
@@ -93,53 +99,61 @@ class Scalar_source_XY(Scalar_field_XY):
         Parameters:
             r0 (float, float): (x,y) position of center
             w0 (float, float): (wx,wy) minimum beam width
-            z0 (float): position of beam width
+            z0 (float): (z0x, z0y) position of beam width for each axis (could be different)
+            alpha (float): rotation angle of the axis of the elliptical gaussian amplitude
+            beta (float): rotation angle of the axis of the main directions of the wavefront (it can be different from alpha)
             A (float): maximum amplitude
-            theta (float): angle in radians (direction of propagation)
-            phi (float): angle in radians (direction of propagation)
+            theta (float): angle in radians (angle of k with respect to z))
 
-        Todo:
-            generalize definition
+        References:
         """
 
         if isinstance(w0, (float, int, complex)):
             w0 = (w0, w0)
 
+        if isinstance(z0, (float, int, complex)):
+            z0 = (z0, z0)
+
         w0x, w0y = w0
-        w0 = sqrt(w0x * w0y)
+        # w0 = sqrt(w0x * w0y)
         x0, y0 = r0
-        k = 2 * pi / self.wavelength
+        z0x, z0y = z0
+        k = 2 * np.pi / self.wavelength
 
         # only for x axis.
-        z_rayleigh = k * w0x**2 / 2
+        z_rayleigh_x = k * w0x**2 / 2
+        z_rayleigh_y = k * w0y**2 / 2
 
-        phaseGouy = arctan2(z0, z_rayleigh)
+        phaseGouy_x = np.arctan2(z0x, z_rayleigh_x)
+        phaseGouy_y = np.arctan2(z0y, z_rayleigh_y)
 
-        wx = w0x * sqrt(1 + (z0 / z_rayleigh)**2)
-        wy = w0y * sqrt(1 + (z0 / z_rayleigh)**2)
-        w = sqrt(wx * wy)
+        wx = w0x * np.sqrt(1 + (z0x / z_rayleigh_x)**2)
+        wy = w0y * np.sqrt(1 + (z0y / z_rayleigh_y)**2)
+        # w = sqrt(wx * wy)
 
-        if z0 == 0:
-            R = 1e10
+        if z0x == 0:
+            R_x = 1e10
         else:
-            R = - z0 * (1 + (z_rayleigh / z0)**2)
+            R_x = -z0x * (1 + (z_rayleigh_x / z0x)**2)
 
-        amplitude = A * w0 / w * exp(-(self.X - x0)**2 / (wx**2) -
-                                     (self.Y - y0)**2 / (wy**2))
-        phase1 = exp(1.j * k * (self.X * sin(theta) * sin(phi) +
-                                self.Y * cos(theta) * sin(phi)))
-        phase2 = exp(1j * (k * z0 - phaseGouy + k * (self.X**2 + self.Y**2) /
-                           (2 * R)))
+        if z0y == 0:
+            R_y = 1e10
+        else:
+            R_y = -z0y * (1 + (z_rayleigh_y / z0y)**2)
+
+        amplitude = (A * (w0x / wx) * (w0y / wy) * np.exp(
+            -(self.X * np.cos(alpha) + self.Y * np.sin(alpha) - x0)**2 /
+            (wx**2)) * np.exp(
+                -(-self.X * np.sin(alpha) + self.Y * np.cos(alpha) - y0)**2 /
+                (wy**2)))
+        phase1 = np.exp(1.j * k * (self.X * np.sin(theta) * np.cos(phi) +
+                                   self.Y * np.sin(theta) * np.sin(phi)))
+        phase2 = np.exp(1j * (k * z0x - phaseGouy_x + k * ((self.X * np.cos(beta) + self.Y * np.sin(beta))**2) / (2 * R_x))) * \
+            np.exp(1j * (k * z0y - phaseGouy_y + k * ((-self.X * np.sin(beta) + self.Y * np.cos(beta))**2) / (2 * R_y)))
 
         self.u = amplitude * phase1 * phase2
 
-    def spherical_wave(self,
-                       A=1,
-                       r0=(0 * um, 0 * um),
-                       z0=-1000 * um,
-                       mask=True,
-                       radius=100 * um,
-                       normalize=False):
+    def spherical_wave(self, r0, z0, A=1, radius=0, normalize=False):
         """Spherical wave.
 
         Parameters:
@@ -154,17 +168,14 @@ class Scalar_source_XY(Scalar_field_XY):
         k = 2 * pi / self.wavelength
         x0, y0 = r0
 
-        # Centrado radius de la mask y distance al origen emisor
         R2 = (self.X - x0)**2 + (self.Y - y0)**2
         Rz = sqrt((self.X - x0)**2 + (self.Y - y0)**2 + z0**2)
 
-        # Definicion de la mask circular
-        if mask is True:
+        if radius > 0:
             amplitude = (R2 <= radius**2)
         else:
             amplitude = 1
 
-        # Onda esferica
         self.u = amplitude * A * exp(-1.j * sign(z0) * k * Rz) / Rz
 
         if normalize is True:
@@ -191,17 +202,12 @@ class Scalar_source_XY(Scalar_field_XY):
         x0, y0 = r0
         amplitude = ((self.X - x0) + 1.j * sign(m) *
                      (self.Y - y0))**np.abs(m) * np.exp(-(
-                         (self.X - x0)**2 / w0x**2 + (self.Y - y0)**2 / w0y**2))
+                         (self.X - x0)**2 / w0x**2 +
+                         (self.Y - y0)**2 / w0y**2))
 
         self.u = A * amplitude / np.abs(amplitude).max()
 
-    def hermite_gauss_beam(self, r0,
-                           A,
-                           w0,
-                           n,
-                           m,
-                           z,
-                           z0):
+    def hermite_gauss_beam(self, r0, A, w0, n, m, z, z0):
         """Hermite Gauss beam.
 
         Parameters:
@@ -217,11 +223,9 @@ class Scalar_source_XY(Scalar_field_XY):
              hermite_gauss_beam(A=1, r0=(0,0), w0=(100*um, 50*um), n=2, m=3, z=0)
         """
         # Prepare space
-        # E = zeros(self.X.shape, dtype=np.float)
         X = self.X - r0[0]
         Y = self.Y - r0[1]
 
-        # Parameters
         r2 = sqrt(2)
 
         if isinstance(w0, (float, int, complex)):
@@ -314,38 +318,32 @@ class Scalar_source_XY(Scalar_field_XY):
 
         self.u = A * Er * Ef
 
-    def zernike_beam(self, A, r0, radius, n, m, c_nm, mask=True):
+    def zernike_beam(self, A, r0, radius, n, m, c_nm):
         """Zernike beam.
 
         Parameters:
-            A (float): amplitude of the Hermite Gauss beam
+            A (float): amplitude of the Zernike beam beam
             r0 (float, float): (x,y) position of source
             radius (float): width of the beam
             n (list): list of integers with orders
             m (list): list of integers with orders
             c_nm (list): list of integers with coefficients
-            mask (bool): if True a mask of radius is provided
 
         Example:
-             zernike_beam(A=1, r0=(0,0), radius=5 * mm, n=[1, 3, 3, 5, 5, 5], m=[1, 1, 3, 1, 3, 5], c_nm=[.25, 1, 1, 1, 1, 1], mask=True)
+             zernike_beam(A=1, r0=(0,0), radius=5 * mm, n=[1, 3, 3, 5, 5, 5], m=[1, 1, 3, 1, 3, 5], c_nm=[.25, 1, 1, 1, 1, 1])
         """
 
-        # normalizing for radius 1
+        # normalizing to radius 1
         x0, y0 = r0
         R = sqrt((self.X - x0)**2 + (self.Y - y0)**2) / radius
 
         # phase as sum of Zernike functions
-        phase = zeros(self.X.shape, dtype=np.float)
+        phase = zeros(self.X.shape, dtype=float)
         for s in range(len(n)):
             phase = phase + c_nm[s] * fZernike(self.X - x0, self.Y - y0, n[s],
                                                m[s], radius)
 
-        if mask is True:
-            amplitude = (R < 1)
-        else:
-            amplitude = 1
-
-        self.u = A * amplitude * exp(1.j * np.real(phase))
+        self.u = A * exp(1.j * np.real(phase))
 
     def bessel_beam(self,
                     A,
@@ -358,7 +356,7 @@ class Scalar_source_XY(Scalar_field_XY):
         """Bessel beam produced by an axicon. Bessel-beams are generated using 2D axicons.
 
         Parameters:
-            A (float): amplitude of the Hermite Gauss beam
+            A (float): amplitude of the Bessel beam
             r0 (float, float): (x,y) position of source
             alpha (float): angle of the beam generator
             n (int): order of the beam
@@ -367,12 +365,13 @@ class Scalar_source_XY(Scalar_field_XY):
             z0 (float): constant value for phase shift
 
         References:
+            J. Durnin, J. Miceli, and J. H. Eberly, Phys. Rev. Lett. 58, 1499 (1987).
             F. Courvoisier, et al. "Surface nanoprocessing with nondiffracting femtosecond Bessel beams" Optics Letters Vol. 34, No. 20 3163 (2009)
         """
 
+        k = 2 * np.pi / self.wavelength
         x0, y0 = r0
         R = sqrt((self.X - x0)**2 + (self.Y - y0)**2)
-        k = 2 * np.pi / self.wavelength
         beta = k * np.cos(alpha)
 
         if n == 0:
@@ -384,8 +383,8 @@ class Scalar_source_XY(Scalar_field_XY):
 
         self.u = A * jbessel * np.exp(1j * beta * z0) * np.exp(
             1.j * k *
-            (self.X * sin(theta) * sin(phi) + self.Y * cos(theta) * sin(phi)) +
-            z0 * cos(phi))
+            (self.X * sin(theta) * cos(phi) + self.Y * sin(theta) * sin(phi)) +
+            z0 * cos(theta))
 
     def plane_waves_dict(self, params):
         """Several plane waves with parameters defined in dictionary
@@ -404,8 +403,8 @@ class Scalar_source_XY(Scalar_field_XY):
         for p in params:
             self.u = self.u + p['A'] * exp(
                 1.j * k *
-                (self.X * sin(p['theta']) * sin(p['phi']) + self.Y *
-                 cos(p['theta']) * sin(p['phi']) + p['z0'] * cos(p['phi'])))
+                (self.X * sin(p['theta']) * cos(p['phi']) + self.Y *
+                 sin(p['theta']) * sin(p['phi']) + p['z0'] * cos(p['theta'])))
 
     def plane_waves_several_inclined(self, A, num_beams, max_angle, z0=0):
         """Several paralel plane waves
