@@ -9,10 +9,11 @@ import matplotlib.image as mpimg
 import matplotlib.pyplot as plt
 import numpy as np
 
-from . import degrees, eps, mm, params_drawing
+from . import degrees, eps, mm
+from .config import CONF_DRAWING
 from .utils_optics import field_parameters
 
-percentaje_intensity = params_drawing['percentaje_intensity']
+percentage_intensity = CONF_DRAWING['percentage_intensity']
 
 
 def view_image(filename):
@@ -117,12 +118,11 @@ def draw2D(
         xlabel = "x (mm)"
         ylabel = "y (mm)"
 
-    IDimage = plt.imshow(
-        image,
-        interpolation=interpolation,
-        aspect='auto',
-        origin='lower',
-        extent=extension)
+    IDimage = plt.imshow(image,
+                         interpolation=interpolation,
+                         aspect='auto',
+                         origin='lower',
+                         extent=extension)
     plt.xlabel(xlabel)
     plt.ylabel(ylabel)
     plt.suptitle(title)
@@ -174,54 +174,54 @@ def draw_several_fields(fields,
     id_fig = plt.figure(figsize=figsize, facecolor='w', edgecolor='k')
     num_dibujos = len(fields)
 
-    percentaje_intensity = params_drawing['percentaje_intensity']
+    percentage_intensity = CONF_DRAWING['percentage_intensity']
 
     for i in sorted(range(num_dibujos)):
         c = fields[i]
         id_fig.add_subplot(col, fil, i + 1)
         extension = [c.x.min(), c.x.max(), c.y.min(), c.y.max()]
-        amplitude, intensity, phase = field_parameters(
-            c.u, has_amplitude_sign=True)
+        amplitude, intensity, phase = field_parameters(c.u,
+                                                       has_amplitude_sign=True)
 
         if kinds == '':
             image = intensity
-            colormap = params_drawing['color_intensity']
+            colormap = CONF_DRAWING['color_intensity']
             kind = 'intensity'
         else:
             kind = kinds[i]
-            if kinds[i] == 'intensity':
-                image = intensity
-                colormap = params_drawing['color_intensity']
-            elif kinds[i] == 'phase':
-                phase = phase / degrees
-                phase[intensity < percentaje_intensity * (intensity.max())] = 0
+        if kind == 'intensity':
+            image = intensity
+            colormap = CONF_DRAWING['color_intensity']
+        elif kind == 'phase':
+            phase = phase / degrees
+            phase[intensity < percentage_intensity * (intensity.max())] = 0
 
-                colormap = params_drawing['color_phase']
-                image = phase
-            elif kinds[i] == 'amplitude':
-                image = amplitude
-                colormap = params_drawing['color_amplitude']
-            elif kinds[i] == 'real':
-                percentaje_intensity = params_drawing['percentaje_intensity']
-                rf = np.real(c.u)
-                intensity = np.abs(c.u)**2
-                rf[intensity < percentaje_intensity * (intensity.max())] = 0
+            colormap = CONF_DRAWING['color_phase']
+            image = phase
+        elif kind == 'amplitude':
+            image = amplitude
+            colormap = CONF_DRAWING['color_amplitude']
+        elif kind == 'real':
+            percentage_intensity = CONF_DRAWING['percentage_intensity']
+            rf = np.real(c.u)
+            intensity = np.abs(c.u)**2
+            rf[intensity < percentage_intensity * (intensity.max())] = 0
 
-                image = np.real(c.u)
-                colormap = params_drawing['color_real']
+            image = np.real(c.u)
+            colormap = CONF_DRAWING['color_real']
 
-            if logarithm is True and kinds[i] in ('intensity', 'amplitude', 'real'):
-                image = np.log(image + 1)
+        if logarithm > 0 and kind in ('intensity', 'amplitude', 'real'):
+            image = np.log(logarithm * image + 1)
 
-            if normalize == 'maximum' and kinds[i] in ('intensity', 'amplitude', 'real'):
-                image = image / image.max()
+        if normalize == 'maximum' and kind in ('intensity', 'amplitude',
+                                               'real'):
+            image = image / image.max()
 
-        plt.imshow(
-            image,
-            interpolation='bilinear',
-            aspect='auto',
-            origin='lower',
-            extent=extension)
+        plt.imshow(image,
+                   interpolation='bilinear',
+                   aspect='auto',
+                   origin='lower',
+                   extent=extension)
 
         plt.set_cmap(colormap)
         if titles != '':
@@ -230,7 +230,7 @@ def draw_several_fields(fields,
         plt.suptitle(title, fontsize=26)
         plt.axis('scaled')
         plt.axis(extension)
-        plt.colorbar(orientation='horizontal', shrink=0.5)
+        plt.colorbar(orientation='horizontal', fraction=0.046)
         if kind == 'phase':
             plt.clim(-180, 180)
 
