@@ -4,15 +4,222 @@
 
 from copy import deepcopy
 from math import factorial
-
 import numpy as np
+
+from numpy import (array, exp, ones_like, pi, linspace, tile, angle, zeros)
+
 import scipy.ndimage as ndimage
-from numpy import angle, array, exp, linspace, ones_like, pi, zeros
 from scipy.signal import fftconvolve
+from numpy.fft import fft, ifft
 
 from . import mm
 
 
+def nextpow2(x):
+    """Exponent of next higher power of 2. It returns the exponents for the smallest powers of two that satisfy $2^p≥A$ for each element in A. 
+    By convention, nextpow2(0) returns zero.
+
+    Parameters:
+        x (float): value
+
+    Returns:
+        integer: Exponent of next higher power of 2
+    """
+    y = np.ceil(np.log2(x))
+    if type(x) is np.ndarray:
+        y[y == -np.inf] = 0
+        return y
+    else:
+        if y == -np.inf:
+            y = 0
+        return int(y)
+
+
+# def Bluestein_dft_x(x, f1, f2, fs, mout):
+#     """Bluestein dft
+
+#     Parameters:
+#         x (_type_): _description_
+#         f1 (_type_): _description_
+#         f2 (_type_): _description_
+#         fs (_type_): _description_
+#         mout (_type_): _description_
+
+#     Reference:
+#         - Hu, Y., Wang, Z., Wang, X., Ji, S., Zhang, C., Li, J., Zhu, W., Wu, D.,  Chu, J. (2020). "Efficient full-path optical calculation of scalar and vector diffraction using the Bluestein method". Light: Science and Applications, 9(1). https://doi.org/10.1038/s41377-020-00362-z
+#     """
+
+#     m = len(x)
+#     f11 = f1 + (mout * fs + f2 - f1) / (2 * mout)
+#     f22 = f2 + (mout * fs + f2 - f1) / (2 * mout)
+#     a = exp(1j * 2 * pi * f11 / fs)
+#     w = exp(-1j * 2 * pi * (f22 - f11) / (mout * fs))
+#     h = np.arange(-m + 1, max(mout, m))
+#     mp = m + mout - 1
+#     h = w**((h**2) / 2)
+#     ft = fft(1 / h[0:mp + 1], 2**nextpow2(mp))
+#     b = a**(-(np.arange(0, m))) * h[np.arange(m - 1, 2 * m - 1)]
+#     tmp = b.T
+#     b = fft(x * tmp, 2**nextpow2(mp), axis=0)
+
+#     b = ifft(b * ft.T, axis=0)
+#     b = b[m:mp + 1].T * h[m - 1:mp]
+#     l = linspace(0, mout - 1, mout)
+#     l = l / mout * (f22 - f11) + f11
+#     Mshift = -m / 2
+#     Mshift = exp(-1j * 2 * pi * l * (Mshift + 1 / 2) / fs)
+#     b = b * Mshift
+
+#     return b
+
+
+def Bluestein_dft_x(x, f1, f2, fs, mout):
+    """Bluestein dft
+
+    Parameters:
+        x (_type_): _description_
+        f1 (_type_): _description_
+        f2 (_type_): _description_
+        fs (_type_): _description_
+        mout (_type_): _description_
+
+    Reference:
+        - Hu, Y., Wang, Z., Wang, X., Ji, S., Zhang, C., Li, J., Zhu, W., Wu, D.,  Chu, J. (2020). "Efficient full-path optical calculation of scalar and vector diffraction using the Bluestein method". Light: Science and Applications, 9(1). https://doi.org/10.1038/s41377-020-00362-z
+    """
+    # print("mout = {}".format(mout))
+
+    m = len(x)
+    # print("m (len(x)) = {}".format(m))
+
+    f11 = f1 + (mout * fs + f2 - f1) / (2 * mout)
+    f22 = f2 + (mout * fs + f2 - f1) / (2 * mout)
+    a = np.exp(1j * 2 * np.pi * f11 / fs)
+    w = np.exp(-1j * 2 * np.pi * (f22 - f11) / (mout * fs))
+    h = np.arange(-m + 1, max(mout, m))
+    mp = m + mout - 1
+    h = w**((h**2) / 2)
+    ft = fft(1 / h[0:mp + 1], 2**nextpow2(mp))
+    b = a**(-(np.arange(0, m))) * h[np.arange(m - 1, 2 * m - 1)]
+    tmp = b.T
+    b = fft(x * tmp, 2**nextpow2(mp), axis=0)
+
+    b = ifft(b * ft.T, axis=0)
+    # b = b[m:mp + 1].T * h[m - 1:mp]
+    # Nuevo:
+    # print("b = {}".format(b))
+    if mout > 1:
+        b = b[m:mp + 1].T * h[m - 1:mp]
+    else:
+        b = b[0] * h[0]
+    l = np.linspace(0, mout - 1, mout)
+    l = l / mout * (f22 - f11) + f11
+    # print("b = {}".format(b))
+    # print("l = {}".format(l))
+
+    Mshift = -m / 2
+    Mshift = np.exp(-1j * 2 * np.pi * l * (Mshift + 1 / 2) / fs)
+    # print("Mshift = {}".format(Mshift))
+
+    b = b * Mshift
+
+    return b
+
+
+def Bluestein_dft_xy(x, f1, f2, fs, mout):
+    """Bluestein dft
+
+    Parameters:
+        x (_type_): _description_
+        f1 (_type_): _description_
+        f2 (_type_): _description_
+        fs (_type_): _description_
+        mout (_type_): _description_
+    """
+    verbose = False
+
+    m, n = x.shape
+    f11 = f1 + (mout * fs + f2 - f1) / (2 * mout)
+    f22 = f2 + (mout * fs + f2 - f1) / (2 * mout)
+    a = np.exp(1j * 2 * np.pi * f11 / fs)
+    w = np.exp(-1j * 2 * np.pi * (f22 - f11) / (mout * fs))
+    h = np.arange(-m + 1, max(mout, m))
+    mp = m + mout - 1
+    h = w**((h**2) / 2)
+    ft = fft(1 / h[0:mp + 1], 2**nextpow2(mp))
+    b = a**(-(np.arange(0, m))) * h[np.arange(m - 1, 2 * m - 1)]
+    tmp = np.tile(b, (n, 1)).T
+    b = fft(x * tmp, 2**nextpow2(mp), axis=0)
+    b = ifft(b * np.tile(ft, (n, 1)).T, axis=0)
+
+    if verbose:
+        print("b = {}".format(b))
+
+    if mout > 1:
+        b = b[m:mp + 1, 0:n].T * np.tile(h[m - 1:mp], (n, 1))
+    else:
+        b = b[0] * h[0]
+
+    l = np.linspace(0, mout - 1, mout)
+    l = l / mout * (f22 - f11) + f11
+
+    if verbose:
+        print("b = {}".format(b))
+        print("l = {}".format(l))
+
+    Mshift = -m / 2
+    Mshift = np.tile(np.exp(-1j * 2 * np.pi * l * (Mshift + 1 / 2) / fs),
+                     (n, 1))
+    b = b * Mshift
+
+    return b
+
+
+def Bluestein_dft_xy_backup(x, f1, f2, fs, mout):
+    """Bluestein dft
+
+    Parameters:
+        x (_type_): _description_
+        f1 (_type_): _description_
+        f2 (_type_): _description_
+        fs (_type_): _description_
+        mout (_type_): _description_
+    """
+
+    m, n = x.shape
+    f11 = f1 + (mout * fs + f2 - f1) / (2 * mout)
+    f22 = f2 + (mout * fs + f2 - f1) / (2 * mout)
+    a = exp(1j * 2 * pi * f11 / fs)
+    w = exp(-1j * 2 * pi * (f22 - f11) / (mout * fs))
+    h = np.arange(-m + 1, max(mout, m))
+    mp = m + mout - 1
+    h = w**((h**2) / 2)
+    ft = fft(1 / h[0:mp + 1], 2**nextpow2(mp))
+    b = a**(-(np.arange(0, m))) * h[np.arange(m - 1, 2 * m - 1)]
+    tmp = tile(b, (n, 1)).T
+    b = fft(x * tmp, 2**nextpow2(mp), axis=0)
+
+    b = ifft(b * tile(ft, (n, 1)).T, axis=0)
+    b = b[m:mp + 1, 0:n].T * tile(h[m - 1:mp], (n, 1))
+    l = np.linspace(0, mout - 1, mout)
+    l = l / mout * (f22 - f11) + f11
+    Mshift = -m / 2
+    Mshift = tile(exp(-1j * 2 * pi * l * (Mshift + 1 / 2) / fs), (n, 1))
+    b = b * Mshift
+
+    return b
+
+
+def reduce_to_1(class_diffractio):
+    """All the values greater than 1 pass to 1. This is used for Scalar_masks when we add two masks.
+    Parameters:
+        class (class): Scalar_field_X, XY ,....
+
+    """
+    class_diffractio.u[np.abs(class_diffractio.u > 1)] = 1
+
+    return class_diffractio
+
+
 def distance(x1, x2):
     """Compute distance between two vectors.
 
@@ -91,7 +298,7 @@ def find_extrema(array2D, x, y, kind='max', verbose=False):
 
     num_extrema = len(listOfCordinates)
 
-    indexes = np.zeros((num_extrema, 2), dtype=np.integer)
+    indexes = np.zeros((num_extrema, 2), dtype=int)
     xy_ext = np.zeros((num_extrema, 2))
     extrema = np.zeros((num_extrema))
 
@@ -109,7 +316,7 @@ def find_extrema(array2D, x, y, kind='max', verbose=False):
 
 
 def ndgrid(*args, **kwargs):
-    """n-dimensional gridding like Matlab's NDGRID
+    """n-dimensional gridding like Matlab's NDGRID.
 
     Parameters:
         The input *args are an arbitrary number of numerical sequences, e.g. lists, arrays, or tuples.
@@ -121,57 +328,57 @@ def ndgrid(*args, **kwargs):
         >>> x, y, z = [0, 1], [2, 3, 4], [5, 6, 7, 8]
 
         >>> X, Y, Z = ndgrid(x, y, z)
-        # unpacking the returned ndarray into X, Y, Z
+            # unpacking the returned ndarray into X, Y, Z
 
         Each of X, Y, Z has shape [len(v) for v in x, y, z].
 
         >>> X.shape == Y.shape == Z.shape == (2, 3, 4)
-        True
+            True
 
         >>> X
-        array([[[0, 0, 0, 0],
-                        [0, 0, 0, 0],
-                        [0, 0, 0, 0]],
-                   [[1, 1, 1, 1],
-                        [1, 1, 1, 1],
-                        [1, 1, 1, 1]]])
+            array([[[0, 0, 0, 0],
+                            [0, 0, 0, 0],
+                            [0, 0, 0, 0]],
+                    [[1, 1, 1, 1],
+                            [1, 1, 1, 1],
+                            [1, 1, 1, 1]]])
         >>> Y
-        array([[[2, 2, 2, 2],
-                        [3, 3, 3, 3],
-                        [4, 4, 4, 4]],
-                   [[2, 2, 2, 2],
-                        [3, 3, 3, 3],
-                        [4, 4, 4, 4]]])
+            array([[[2, 2, 2, 2],
+                            [3, 3, 3, 3],
+                            [4, 4, 4, 4]],
+                    [[2, 2, 2, 2],
+                            [3, 3, 3, 3],
+                            [4, 4, 4, 4]]])
         >>> Z
-        array([[[5, 6, 7, 8],
-                        [5, 6, 7, 8],
-                        [5, 6, 7, 8]],
-                   [[5, 6, 7, 8],
-                        [5, 6, 7, 8],
-                        [5, 6, 7, 8]]])
+            array([[[5, 6, 7, 8],
+                            [5, 6, 7, 8],
+                            [5, 6, 7, 8]],
+                    [[5, 6, 7, 8],
+                            [5, 6, 7, 8],
+                            [5, 6, 7, 8]]])
 
         With an unpacked argument list:
 
         >>> V = [[0, 1], [2, 3, 4]]
 
         >>> ndgrid(*V) # an array of two arrays with shape (2, 3)
-        array([[[0, 0, 0],
-                        [1, 1, 1]],
-                   [[2, 3, 4],
-                        [2, 3, 4]]])
+            array([[[0, 0, 0],
+                [1, 1, 1]],
+                [[2, 3, 4],
+                [2, 3, 4]]])
 
         For input vectors of different data kinds,
         same_dtype=False makes ndgrid()
         return a list of arrays with the respective dtype.
         >>> ndgrid([0, 1], [1.0, 1.1, 1.2], same_dtype=False)
         [array([[0, 0, 0], [1, 1, 1]]),
-         array([[ 1. ,  1.1,  1.2], [ 1. ,  1.1,  1.2]])]
+        array([[ 1. ,  1.1,  1.2], [ 1. ,  1.1,  1.2]])]
 
         Default is to return a single array.
 
         >>> ndgrid([0, 1], [1.0, 1.1, 1.2])
-        array([[[ 0. ,  0. ,  0. ], [ 1. ,  1. ,  1. ]],
-                   [[ 1. ,  1.1,  1.2], [ 1. ,  1.1,  1.2]]])
+            array([[[ 0. ,  0. ,  0. ], [ 1. ,  1. ,  1. ]],
+                [[ 1. ,  1.1,  1.2], [ 1. ,  1.1,  1.2]]])
     """
     same_dtype = kwargs.get("same_dtype", True)
     V = [array(v) for v in args]  # ensure all input vectors are arrays
@@ -190,28 +397,6 @@ def ndgrid(*args, **kwargs):
         return result  # keeps separate dtype for each output
 
 
-# def meshgrid2(*arrs):
-#     arrs = tuple(reversed(arrs))  # edit
-#     lens = map(len, arrs)
-#     dim = len(arrs)
-#
-#     sz = 1
-#     for s in lens:
-#         sz *= s
-#
-#     ans = []
-#     for i, arr in enumerate(arrs):
-#         slc = [1] * dim
-#         slc[i] = lens[i]
-#         arr2 = np.asarray(arr).reshape(slc)
-#         for j, sz in enumerate(lens):
-#             if j != i:
-#                 arr2 = arr2.repeat(sz, axis=j)
-#         ans.append(arr2)
-#
-#     return tuple(ans)
-
-
 def get_amplitude(u, sign=False):
     """Gets the amplitude of the field.
 
@@ -293,32 +478,6 @@ def normalize(v, order=2):
     return v / norm
 
 
-#
-# def normalize_field(u, kind='intensity'):
-#     """Normalize the field.
-#
-#     Parameters:
-#         u (np.array): field
-#         kind (str): normalization parameter -'intensity' 'area'
-#
-#     Returns:
-#         normalized value
-#
-#
-#     """
-#
-#     if kind == 'intensity':
-#         intensity = np.abs(u**2)
-#         maximum = sqrt(intensity.max())
-#         u = u / maximum
-#     if kind == 'area':
-#         intensity = np.abs(u**2)
-#         maximum = intensity.sum()
-#         u = u / maximum
-#
-#         return u
-
-
 def binarize(vector, min_value=0, max_value=1):
     """Binarizes vector between two levels, min and max. The central value is (min_value+max_value)/2
 
@@ -380,7 +539,7 @@ def discretize(u,
         fieldDiscretizado = discretized_image * phase
 
     if kind == 'phase':
-        ang = angle(get_phase(UnboundLocalError)) + phase0 + pi
+        ang = angle(get_phase(u)) + phase0 + pi
         ang = ang % (2 * pi)
         amplitude = get_amplitude(u)
 
@@ -553,14 +712,12 @@ def get_edges(x,
         print(np.array([raising, falling]).T)
 
     if not filename == '':
-        np.savetxt(
-            "{}_pos_transitions.txt".format(filename),
-            pos_transitions,
-            fmt='%10.6f')
-        np.savetxt(
-            "{}_type_transitions.txt".format(filename),
-            type_transitions,
-            fmt='%10.6f')
+        np.savetxt("{}_pos_transitions.txt".format(filename),
+                   pos_transitions,
+                   fmt='%10.6f')
+        np.savetxt("{}_type_transitions.txt".format(filename),
+                   type_transitions,
+                   fmt='%10.6f')
         np.savetxt("{}_raising.txt".format(filename), raising, fmt='%10.6f')
         np.savetxt("{}_falling.txt".format(filename), falling, fmt='%10.6f')
 
@@ -628,9 +785,8 @@ def fft_filter(x, y, normalize=False):
 
     y = y / y.sum()
 
-    return fftconvolve(
-        x, y, mode='same') / fftconvolve(
-            x, np.ones_like(y) / sum(y), mode='same')
+    return fftconvolve(x, y, mode='same') / fftconvolve(
+        x, np.ones_like(y) / sum(y), mode='same')
 
 
 def fft_correlation1d(x, y):
@@ -763,12 +919,12 @@ def fZernike(X, Y, n, m, radius=5 * mm):
 
     N = np.sqrt((n + 1) * (2 - delta_kronecker(m, 0)))
 
-    Z = zeros(R.shape, dtype=np.float)
-    for s in np.arange(0, (n - np.abs(m)) / 2 + 1):
-        Z = Z + (-1)**s * R**(n - 2 * s) * factorial(
-            np.abs(n - s)) / (factorial(np.abs(s)) * factorial(
-                np.abs(round(0.5 * (n + np.abs(m)) - s))) * factorial(
-                    np.abs(round(0.5 * (n - np.abs(m)) - s))))
+    Z = zeros(R.shape, dtype=float)
+    s_max = int(((n - abs(m)) / 2 + 1))
+    for s in np.arange(0, s_max):
+        Z = Z + (-1)**s * R**(n - 2 * s) * factorial(abs(n - s)) / (
+            factorial(abs(s)) * factorial(abs(round(0.5 * (n + abs(m)) - s))) *
+            factorial(abs(round(0.5 * (n - abs(m)) - s))))
 
     if m >= 0:
         fz1 = N * Z * np.cos(m * THETA)
@@ -815,8 +971,8 @@ def laguerre_polynomial_nk(x, n=4, k=5):
     f = factorial
     summation = np.zeros_like(x, dtype=float)
     for m in range(n + 1):
-        summation = summation + (-1)**m * f(n + k) / (
-            f(n - m) * f(k + m) * f(m)) * x**m
+        summation = summation + (-1)**m * f(n + k) / (f(n - m) * f(k + m) *
+                                                      f(m)) * x**m
     return summation
 
 
