@@ -27,6 +27,7 @@ if not os.path.exists(newpath):
 
 
 class Test_Scalar_masks_X(object):
+
     def test_slit(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
@@ -120,10 +121,7 @@ class Test_Scalar_masks_X(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_X(x, wavelength)
-        t1.biprism_fresnel(angle=1 * degrees,
-                           x0=100 * um,
-                           radius=125,
-                           mask=True)
+        t1.biprism_fresnel(angle=1 * degrees, x0=100 * um, radius=125)
         t1.draw(kind='phase')
 
         t1.save_data(filename=filename + '.npz')
@@ -176,7 +174,6 @@ class Test_Scalar_masks_X(object):
         t1.fresnel_lens(x0=0 * um,
                         radius=100 * um,
                         focal=.25 * mm,
-                        mask=True,
                         kind='amplitude',
                         phase=np.pi)
         t1.draw(kind='amplitude')
@@ -185,7 +182,6 @@ class Test_Scalar_masks_X(object):
         t1.fresnel_lens(x0=0 * um,
                         radius=100 * um,
                         focal=.25 * mm,
-                        mask=True,
                         kind='phase',
                         phase=np.pi)
         t1.draw(kind='phase')
@@ -221,7 +217,7 @@ class Test_Scalar_masks_X(object):
         x = np.linspace(-500 * um, 500 * um, 2048)
 
         t1 = Scalar_mask_X(x, wavelength)
-        t1.dust_different_sizes(percentaje=0.2, size=20 * um, std=5 * um)
+        t1.dust_different_sizes(percentage=0.2, size=20 * um, std=5 * um)
         t1.draw()
 
         t1.save_data(filename=filename + '.npz')
@@ -237,7 +233,7 @@ class Test_Scalar_masks_X(object):
         x = np.linspace(-500 * um, 500 * um, 2048 * 8)
 
         t1 = Scalar_mask_X(x, wavelength)
-        t1.dust(percentaje=0.9, size=20 * um)
+        t1.dust(percentage=0.9, size=20 * um)
         t1.draw()
 
         t1.save_data(filename=filename + '.npz')
@@ -355,8 +351,7 @@ class Test_Scalar_masks_X(object):
                               f1=f1,
                               f2=f2,
                               v_globals=v_globals,
-                              radius=100 * um,
-                              mask=True)
+                              radius=100 * um)
         t1.draw(kind='phase')
 
         t1.save_data(filename=filename + '.npz')
@@ -388,8 +383,7 @@ class Test_Scalar_masks_X(object):
                            array1=profile1 * mm,
                            array2=profile2 * mm,
                            interp_kind='quadratic',
-                           radius=1.5 * mm,
-                           mask=True)
+                           radius=1.5 * mm)
 
         t1.draw(kind='phase')
 
@@ -485,15 +479,20 @@ class Test_Scalar_masks_X(object):
         x = np.linspace(0, anchura_bit * len(code), num_data)
 
         t1 = Scalar_mask_X(x, wavelength)
-        t1.binary_code(kind='normal', code=code,
-                       bit_width=anchura_bit, x0=0 * um)
+        t1.binary_code(kind='normal',
+                       code=code,
+                       bit_width=anchura_bit,
+                       x0=0 * um)
         t1.draw()
 
         t1.save_data(filename=filename + '-normal' + '.npz')
         save_figure_test(newpath, func_name + '-normal')
 
         t2 = Scalar_mask_X(x, wavelength)
-        t2.binary_code(x0=0 * um, kind='zeros', code=code, bit_width=anchura_bit)
+        t2.binary_code(x0=0 * um,
+                       kind='zeros',
+                       code=code,
+                       bit_width=anchura_bit)
         t2.draw()
 
         t2.save_data(filename=filename + '-zeros' + '.npz')
