@@ -26,6 +26,7 @@ if not os.path.exists(newpath):
 
 
 class Test_Scalar_masks_XY(object):
+
     def test_add(self):
         func_name = sys._getframe().f_code.co_name
         filename = '{}{}'.format(newpath, func_name)
@@ -37,20 +38,21 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.square(
-            r0=(-50 * um, 0 * um), size=(50 * um, 50 * um), angle=0 * degrees)
+        t1.square(r0=(-50 * um, 0 * um),
+                  size=(50 * um, 50 * um),
+                  angle=0 * degrees)
         t1.draw(title='test_square')
 
         t2 = Scalar_mask_XY(x, y, wavelength)
-        t2.circle(
-            r0=(50 * um, 0 * um), radius=(25 * um, 25 * um), angle=0 * degrees)
+        t2.circle(r0=(50 * um, 0 * um),
+                  radius=(25 * um, 25 * um),
+                  angle=0 * degrees)
         t2.draw(title='test_square')
 
         t3 = t2 + t1
         t3.draw(title='suma')
 
-        t1.save_data(
-            filename=filename + '.npz', add_name='_1')
+        t1.save_data(filename=filename + '.npz', add_name='_1')
         save_figure_test(newpath, func_name, add_name='_1')
 
         func_name = sys._getframe().f_code.co_name
@@ -63,24 +65,21 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.square(
-            r0=(-50 * um, 0 * um),
-            size=(150 * um, 150 * um),
-            angle=0 * degrees)
+        t1.square(r0=(-50 * um, 0 * um),
+                  size=(150 * um, 150 * um),
+                  angle=0 * degrees)
         t1.draw(title='test_square')
 
         t2 = Scalar_mask_XY(x, y, wavelength)
-        t2.circle(
-            r0=(50 * um, 0 * um),
-            radius=(125 * um, 125 * um),
-            angle=0 * degrees)
+        t2.circle(r0=(50 * um, 0 * um),
+                  radius=(125 * um, 125 * um),
+                  angle=0 * degrees)
         t2.draw(title='test_square')
 
         t3 = t2 + t1
         t3.draw(title='add')
 
-        t3.save_data(
-            filename=filename + '.npz', add_name='_2')
+        t3.save_data(filename=filename + '.npz', add_name='_2')
         save_figure_test(newpath, func_name, add_name='_2')
         assert True
 
@@ -95,13 +94,15 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.square(
-            r0=(0 * um, 0 * um), size=(100 * um, 100 * um), angle=0 * degrees)
+        t1.square(r0=(0 * um, 0 * um),
+                  size=(100 * um, 100 * um),
+                  angle=0 * degrees)
         t1.draw(title='test_square')
 
         t2 = Scalar_mask_XY(x, y, wavelength)
-        t2.circle(
-            r0=(0 * um, 0 * um), radius=(45 * um, 45 * um), angle=0 * degrees)
+        t2.circle(r0=(0 * um, 0 * um),
+                  radius=(45 * um, 45 * um),
+                  angle=0 * degrees)
         t2.draw(title='test_circle')
 
         t3 = t2 - t1
@@ -125,25 +126,24 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.double_slit(
-            x0=0, size=5 * um, separation=15 * um, angle=0 * degrees)
+        t1.double_slit(x0=0,
+                       size=5 * um,
+                       separation=15 * um,
+                       angle=0 * degrees)
         t1.draw(kind='field')
         plt.title('(0,1)-sin binarizar')
-        t1.save_data(
-            filename=filename + '.npz', add_name='_wo_bin')
+        t1.save_data(filename=filename + '.npz', add_name='_wo_bin')
         save_figure_test(newpath, func_name, '_wo_bin')
-        t1.binarize(
-            kind='amplitude',
-            corte=None,
-            level0=0.25,
-            level1=.75,
-            new_field=False,
-            matrix=False)
+        t1.binarize(kind='amplitude',
+                    bin_level=None,
+                    level0=0.25,
+                    level1=.75,
+                    new_field=False,
+                    matrix=False)
         t1.draw(kind='field')
         plt.suptitle('binarizada')
 
-        t1.save_data(
-            filename=filename + '.npz', add_name='_wi_bin')
+        t1.save_data(filename=filename + '.npz', add_name='_wi_bin')
         save_figure_test(newpath, func_name, add_name='_wi_bin')
         assert True
 
@@ -174,13 +174,12 @@ class Test_Scalar_masks_XY(object):
         wavelength = 1 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.sinusoidal_slit(
-            x0=0 * um,
-            size=90,
-            amplitude=30 * um,
-            phase=0 * degrees,
-            angle=0 * degrees,
-            period=100 * um)
+        t1.sinusoidal_slit(x0=0 * um,
+                           size=90,
+                           amplitude=30 * um,
+                           phase=0 * degrees,
+                           angle=0 * degrees,
+                           period=100 * um)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -201,8 +200,14 @@ class Test_Scalar_masks_XY(object):
         a_coef2 = np.array([[0, 1, 2], [0, 25, 25]])
 
         t1 = Scalar_mask_XY(x=x0, y=y0, wavelength=wavelength)
-        t1.slit_series(x0=0, width=200, period1=100, period2=100, Dy=(0, 0),
-                       a_coef1=a_coef1, a_coef2=a_coef2, angle=0 * degrees)
+        t1.slit_series(x0=0,
+                       width=200,
+                       period1=100,
+                       period2=100,
+                       Dy=(0, 0),
+                       a_coef1=a_coef1,
+                       a_coef2=a_coef2,
+                       angle=0 * degrees)
         t1.draw()
 
         t1.save_data(filename=filename + '.npz')
@@ -219,11 +224,10 @@ class Test_Scalar_masks_XY(object):
 
         t1 = Scalar_mask_XY(x, y, wavelength)
 
-        t1.super_ellipse(
-            r0=(0, 0),
-            radius=(20 * um, 40 * um),
-            angle=0 * degrees,
-            n=[0.5, 4])
+        t1.super_ellipse(r0=(0, 0),
+                         radius=(20 * um, 40 * um),
+                         angle=0 * degrees,
+                         n=[0.5, 4])
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -240,11 +244,10 @@ class Test_Scalar_masks_XY(object):
 
         t1 = Scalar_mask_XY(x, y, wavelength)
 
-        t1.super_ellipse(
-            r0=(0, 0),
-            radius=(20 * um, 40 * um),
-            angle=0 * degrees,
-            n=[0.5, 4])
+        t1.super_ellipse(r0=(0, 0),
+                         radius=(20 * um, 40 * um),
+                         angle=0 * degrees,
+                         n=[0.5, 4])
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -262,8 +265,10 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.double_slit(
-            x0=0, size=5 * um, separation=15 * um, angle=0 * degrees)
+        t1.double_slit(x0=0,
+                       size=5 * um,
+                       separation=15 * um,
+                       angle=0 * degrees)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -295,15 +300,15 @@ class Test_Scalar_masks_XY(object):
         wavelength = 1 * um
 
         s = Scalar_mask_XY(x, y, wavelength)
-        s.cross(
-            r0=(0 * um, 0 * um), size=(90 * um, 25 * um), angle=0 * degrees)
+        s.cross(r0=(0 * um, 0 * um),
+                size=(90 * um, 25 * um),
+                angle=0 * degrees)
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.insert_array_masks(
-            t1=s,
-            space=[100 * um, 100 * um],
-            margin=50 * um,
-            angle=90 * degrees)
+        t1.insert_array_masks(t1=s,
+                              space=[100 * um, 100 * um],
+                              margin=50 * um,
+                              angle=90 * degrees)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -321,8 +326,9 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.square(
-            r0=(0 * um, 0 * um), size=(100 * um, 50 * um), angle=45 * degrees)
+        t1.square(r0=(0 * um, 0 * um),
+                  size=(100 * um, 50 * um),
+                  angle=45 * degrees)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -358,11 +364,10 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.super_gauss(
-            r0=(0 * um, 0 * um),
-            radius=(length / 3, length / 3),
-            angle=45 * degrees,
-            potencia=22)
+        t1.super_gauss(r0=(0 * um, 0 * um),
+                       radius=(length / 3, length / 3),
+                       angle=45 * degrees,
+                       power=22)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -380,12 +385,11 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.square_circle(
-            s=.75,
-            r0=(0 * um, 0 * um),
-            R1=100 * um,
-            R2=100 * um,
-            angle=0 * degrees)
+        t1.square_circle(s=.75,
+                         r0=(0 * um, 0 * um),
+                         R1=100 * um,
+                         R2=100 * um,
+                         angle=0 * degrees)
         t1.draw(kind='intensity')
         # t2 = t1.fft(remove0=False)
         # t2.draw(logarithm=True)
@@ -424,8 +428,9 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.circle(
-            r0=(0 * um, 0 * um), radius=(50 * um, 25 * um), angle=45 * degrees)
+        t1.circle(r0=(0 * um, 0 * um),
+                  radius=(50 * um, 25 * um),
+                  angle=45 * degrees)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -443,11 +448,10 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.ring(
-            r0=(0 * um, 0 * um),
-            radius1=(50 * um, 50 * um),
-            radius2=(100 * um, 150 * um),
-            angle=45 * degrees)
+        t1.ring(r0=(0 * um, 0 * um),
+                radius1=(50 * um, 50 * um),
+                radius2=(100 * um, 150 * um),
+                angle=45 * degrees)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -469,8 +473,9 @@ class Test_Scalar_masks_XY(object):
         outer_radius = np.array([6., 12, 17, 23, 29])
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.rings(r0=(0, 0), inner_radius=inner_radius,
-                 outer_radius=outer_radius, mask=True)
+        t1.rings(r0=(0, 0),
+                 inner_radius=inner_radius,
+                 outer_radius=outer_radius)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -489,8 +494,9 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.cross(
-            r0=(0 * um, 0 * um), size=(200 * um, 75 * um), angle=0 * degrees)
+        t1.cross(r0=(0 * um, 0 * um),
+                 size=(200 * um, 75 * um),
+                 angle=0 * degrees)
         t1.draw(kind='intensity')
 
         t1.save_data(filename=filename + '.npz')
@@ -529,8 +535,12 @@ class Test_Scalar_masks_XY(object):
         b_coef = np.array([[0, 3], [0, 25]])
 
         t1 = Scalar_mask_XY(x=x0, y=y0, wavelength=wavelength)
-        t1.edge_series(r0=(0, 0), period=100, a_coef=a_coef, b_coef=b_coef,
-                       angle=0 * degrees, invert=False)
+        t1.edge_series(r0=(0, 0),
+                       period=100,
+                       a_coef=a_coef,
+                       b_coef=b_coef,
+                       angle=0 * degrees,
+                       invert=False)
         t1.draw()
 
         t1.save_data(filename=filename + '.npz')
@@ -566,14 +576,12 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.mask_from_function(
-            r0=(0 * um, 0 * um),
-            index=1.5,
-            f1='1*degrees*self.Y',
-            f2='1*degrees*self.X',
-            v_globals=None,
-            radius=(100 * um, 100 * um),
-            mask=True)
+        t1.mask_from_function(r0=(0 * um, 0 * um),
+                              index=1.5,
+                              f1='1*degrees*self.Y',
+                              f2='1*degrees*self.X',
+                              v_globals=None,
+                              radius=(100 * um, 100 * um))
         t1.draw(kind='field')
 
         t1.save_data(filename=filename + '.npz')
@@ -609,14 +617,12 @@ class Test_Scalar_masks_XY(object):
         print(v_globals)
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.mask_from_function(
-            r0=(0 * um, 0 * um),
-            index=index,
-            f1=f1,
-            f2=f2,
-            v_globals=v_globals,
-            radius=(100 * um, 100 * um),
-            mask=True)
+        t1.mask_from_function(r0=(0 * um, 0 * um),
+                              index=index,
+                              f1=f1,
+                              f2=f2,
+                              v_globals=v_globals,
+                              radius=(100 * um, 100 * um))
         t1.draw(kind='field')
 
         focal = v_globals['R2'] / (index - 1)
@@ -638,22 +644,20 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t0 = Scalar_mask_XY(x, y, wavelength)
-        t0.lens(
-            r0=(0 * um, 0 * um),
-            radius=(100 * um, 100 * um),
-            focal=(2.5 * mm, 2.5 * mm),
-            angle=0 * degrees)
+        t0.lens(r0=(0 * um, 0 * um),
+                radius=(100 * um, 100 * um),
+                focal=(2.5 * mm, 2.5 * mm),
+                angle=0 * degrees)
         t0.draw(kind='phase')
 
         t0.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.lens(
-            r0=(0 * um, 0 * um),
-            radius=(100 * um, 75 * um),
-            focal=(5 * mm, 2.5 * mm),
-            angle=45 * degrees)
+        t1.lens(r0=(0 * um, 0 * um),
+                radius=(100 * um, 75 * um),
+                focal=(5 * mm, 2.5 * mm),
+                angle=45 * degrees)
         t1.draw(kind='phase')
 
         t1.save_data(filename=filename + '.npz', add_name='_elliptical')
@@ -671,29 +675,25 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.fresnel_lens(
-            r0=(0 * um, 0 * um),
-            radius=(250 * um, 250 * um),
-            focal=(5 * mm, 5 * mm),
-            angle=45 * degrees,
-            kind='amplitude',
-            phase=np.pi)
+        t1.fresnel_lens(r0=(0 * um, 0 * um),
+                        radius=(250 * um, 250 * um),
+                        focal=(5 * mm, 5 * mm),
+                        angle=45 * degrees,
+                        kind='amplitude',
+                        phase=np.pi)
         t1.draw(kind='intensity')
-        t1.save_data(
-            filename=filename + '.npz', add_name='_int')
+        t1.save_data(filename=filename + '.npz', add_name='_int')
         save_figure_test(newpath, func_name, add_name='_int')
 
-        t1.fresnel_lens(
-            r0=(0 * um, 0 * um),
-            radius=(250 * um, 250 * um),
-            focal=(5 * mm, 5 * mm),
-            angle=0 * degrees,
-            kind='phase',
-            phase=np.pi)
+        t1.fresnel_lens(r0=(0 * um, 0 * um),
+                        radius=(250 * um, 250 * um),
+                        focal=(5 * mm, 5 * mm),
+                        angle=0 * degrees,
+                        kind='phase',
+                        phase=np.pi)
         t1.draw(kind='phase')
 
-        t1.save_data(
-            filename=filename + '.npz', add_name='_phase')
+        t1.save_data(filename=filename + '.npz', add_name='_phase')
         save_figure_test(newpath, func_name, add_name='_phase')
         assert True
 
@@ -708,8 +708,10 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.biprism_fresnel(
-            r0=(0 * um, 0 * um), width=100 * um, height=5 * um, n=1.5)
+        t1.biprism_fresnel(r0=(0 * um, 0 * um),
+                           width=100 * um,
+                           height=5 * um,
+                           n=1.5)
         t1.draw(kind='field')
         save_figure_test(newpath, func_name)
         t1.save_data(filename=filename + '.npz')
@@ -726,8 +728,10 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.axicon(r0=(0 * um, 0 * um), radius=100 * um,
-                  angle=2 * degrees, refraction_index=1.5)
+        t1.axicon(r0=(0 * um, 0 * um),
+                  radius=100 * um,
+                  angle=2 * degrees,
+                  refraction_index=1.5)
         t1.draw(kind='phase')
 
         save_figure_test(newpath, func_name)
@@ -745,26 +749,26 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t = Scalar_mask_XY(x, y, wavelength)
-        t.laguerre_gauss_spiral(
-            kind='intensity',
-            n=2,
-            l=4,
-            r0=(0 * um, 0 * um),
-            w0=20 * um,
-            z=0.01 * um)
+        t.laguerre_gauss_spiral(kind='intensity',
+                                n=0,
+                                l=4,
+                                r0=(0 * um, 0 * um),
+                                w0=20 * um,
+                                z=100 * um)
         t.draw(kind='intensity')
-        t.save_data(
-            filename=filename + '.npz',
-            add_name='_intensity')
+        t.save_data(filename=filename + '.npz', add_name='_intensity')
         save_figure_test(newpath, func_name, add_name='_intensity')
 
         t2 = Scalar_mask_XY(x, y, wavelength)
-        t2.laguerre_gauss_spiral(
-            kind='phase', n=2, l=4, r0=(0 * um, 0 * um), w0=20 * um, z=0.01 * um)
+        t2.laguerre_gauss_spiral(kind='phase',
+                                 n=0,
+                                 l=16,
+                                 r0=(0 * um, 0 * um),
+                                 w0=20 * um,
+                                 z=4000 * um)
         t2.draw(kind='phase')
 
-        t2.save_data(
-            filename=filename + '.npz', add_name='_phase')
+        t2.save_data(filename=filename + '.npz', add_name='_phase')
         save_figure_test(newpath, func_name, add_name='_phase')
         assert True
 
@@ -779,13 +783,12 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t = Scalar_mask_XY(x, y, wavelength)
-        t.forked_grating(
-            r0=(0 * um, 0 * um),
-            period=20 * um,
-            l=3,
-            alpha=2,
-            kind='amplitude',
-            angle=0 * degrees)
+        t.forked_grating(r0=(0 * um, 0 * um),
+                         period=20 * um,
+                         l=3,
+                         alpha=2,
+                         kind='amplitude',
+                         angle=0 * degrees)
         t.draw(kind='intensity')
 
         t.save_data(filename=filename + '.npz')
@@ -819,8 +822,11 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6238 * um
         period = 50 * um
         red = Scalar_mask_XY(x, y, wavelength)
-        red.sine_grating(
-            period=period, amp_min=0, amp_max=1, x0=0 * um, angle=0 * degrees)
+        red.sine_grating(period=period,
+                         amp_min=0,
+                         amp_max=1,
+                         x0=0 * um,
+                         angle=0 * degrees)
         red.draw(kind='intensity')
 
         red.save_data(filename=filename + '.npz')
@@ -835,8 +841,10 @@ class Test_Scalar_masks_XY(object):
         y = np.linspace(-250 * um, 250 * um, 512)
         wavelength = 0.6238 * um
         red = Scalar_mask_XY(x, y, wavelength)
-        red.ronchi_grating(
-            period=100 * um, x0=0 * um, angle=0 * degrees, fill_factor=0.333)
+        red.ronchi_grating(period=100 * um,
+                           x0=0 * um,
+                           angle=0 * degrees,
+                           fill_factor=0.333)
         red.draw(kind='intensity')
 
         red.save_data(filename=filename + '.npz')
@@ -851,14 +859,13 @@ class Test_Scalar_masks_XY(object):
         y = np.linspace(-250 * um, 250 * um, 512)
         wavelength = 0.6238 * um
         red = Scalar_mask_XY(x, y, wavelength)
-        red.binary_grating(
-            period=50 * um,
-            amin=.5,
-            amax=.75,
-            phase=np.pi,
-            x0=0,
-            fill_factor=0.25,
-            angle=0 * degrees)
+        red.binary_grating(period=50 * um,
+                           amin=.5,
+                           amax=.75,
+                           phase=np.pi,
+                           x0=0,
+                           fill_factor=0.25,
+                           angle=0 * degrees)
         red.draw(kind='field')
 
         red.save_data(filename=filename + '.npz')
@@ -873,14 +880,13 @@ class Test_Scalar_masks_XY(object):
         y = np.linspace(-250 * um, 250 * um, 512)
         wavelength = 0.6238 * um
         red = Scalar_mask_XY(x, y, wavelength)
-        red.binary_grating(
-            period=50 * um,
-            amin=1,
-            amax=1,
-            phase=np.pi / 2,
-            x0=0,
-            fill_factor=0.5,
-            angle=0 * degrees)
+        red.binary_grating(period=50 * um,
+                           amin=1,
+                           amax=1,
+                           phase=np.pi / 2,
+                           x0=0,
+                           fill_factor=0.5,
+                           angle=0 * degrees)
         red.draw(kind='phase')
 
         red.save_data(filename=filename + '.npz')
@@ -896,8 +902,11 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6238 * um
         period = 125 * um
         red = Scalar_mask_XY(x, y, wavelength)
-        red.blazed_grating(
-            period=period, height=2 * um, index=1.5, x0=0, angle=0 * degrees)
+        red.blazed_grating(period=period,
+                           height=2 * um,
+                           index=1.5,
+                           x0=0,
+                           angle=0 * degrees)
         red.draw(kind='phase')
 
         red.save_data(filename=filename + '.npz')
@@ -959,12 +968,10 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6238 * um
 
         t = Scalar_mask_XY(x, y, wavelength)
-        t.circle_rough(
-            r0=(0, 0),
-            radius=100 * um,
-            angle=0 * degrees,
-            sigma=4 * um,
-            correlation_length=.1 * um)
+        t.circle_rough(r0=(0, 0),
+                       radius=100 * um,
+                       angle=0 * degrees,
+                       sigma=4 * um)
         t.draw(kind='intensity')
         t.save_data(filename=filename + '.npz')
         save_figure_test(newpath, func_name)
@@ -979,13 +986,11 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6238 * um
 
         t = Scalar_mask_XY(x, y, wavelength)
-        t.ring_rough(
-            r0=(0, 0),
-            radius1=50 * um,
-            radius2=100 * um,
-            angle=0 * degrees,
-            sigma=4 * um,
-            correlation_length=.1 * um)
+        t.ring_rough(r0=(0, 0),
+                     radius1=50 * um,
+                     radius2=100 * um,
+                     angle=0 * degrees,
+                     sigma=4 * um)
         t.draw(kind='intensity')
 
         t.save_data(filename=filename + '.npz')
@@ -1003,15 +1008,12 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.ring(
-            r0=(0 * um, 0 * um),
-            radius1=(50 * um, 50 * um),
-            radius2=(60 * um, 60 * um),
-            angle=45 * degrees)
+        t1.ring(r0=(0 * um, 0 * um),
+                radius1=(50 * um, 50 * um),
+                radius2=(60 * um, 60 * um),
+                angle=45 * degrees)
         t1.draw()
-        t1.save_data(
-            filename=filename + '.npz',
-            add_name='_no_widened')
+        t1.save_data(filename=filename + '.npz', add_name='_no_widened')
         save_figure_test(newpath, func_name, add_name='_no_widened')
 
         t1.widen(radius=50 * um)
@@ -1020,8 +1022,7 @@ class Test_Scalar_masks_XY(object):
         # t1.u[t1.u >= 0.5] = 1
         t1.draw()
 
-        t1.save_data(
-            filename=filename + '.npz', add_name='_widened')
+        t1.save_data(filename=filename + '.npz', add_name='_widened')
         save_figure_test(newpath, func_name, add_name='_widened')
         assert True
 
@@ -1037,13 +1038,12 @@ class Test_Scalar_masks_XY(object):
         wavelength = 0.6328 * um
 
         t1 = Scalar_mask_XY(x, y, wavelength)
-        t1.circle(
-            r0=(0 * um, 0 * um),
-            radius=(100 * um, 100 * um),
-            angle=0 * degrees)
+        t1.circle(r0=(0 * um, 0 * um),
+                  radius=(100 * um, 100 * um),
+                  angle=0 * degrees)
         t1.draw(title='test_ring')
 
-        area = t1.area(percentaje=0.001)
+        area = t1.area(percentage=0.001)
         text1 = "The area is: {:2.4f} %".format(area * 100)
         plt.title(text1)
 
