@@ -28,6 +28,7 @@ if not os.path.exists(newpath):
 
 
 class Test_Scalar_masks_XYZ(object):
+
     def test_sphere(self):
         func_name = sys._getframe().f_code.co_name
         # filename = '{}{}'.format(newpath, func_name)
@@ -44,16 +45,20 @@ class Test_Scalar_masks_XYZ(object):
         wavelength = 0.55 * um
 
         t1 = Scalar_mask_XY(x=x0, y=y0, wavelength=wavelength)
-        t1.circle(
-            r0=(0 * um, 0 * um), radius=(20 * um, 20 * um), angle=0 * degrees)
+        t1.circle(r0=(0 * um, 0 * um),
+                  radius=(20 * um, 20 * um),
+                  angle=0 * degrees)
 
-        uxyz = Scalar_mask_XYZ(
-            x=x0, y=y0, z=z0, wavelength=wavelength, n_background=1., info='')
-        uxyz.sphere(
-            r0=(0 * um, 0 * um, 0 * um),
-            radius=(10 * um, 30 * um, 50 * um),
-            refraction_index=2,
-            angles=(0 * degrees, 0 * degrees, 45 * degrees))
+        uxyz = Scalar_mask_XYZ(x=x0,
+                               y=y0,
+                               z=z0,
+                               wavelength=wavelength,
+                               n_background=1.,
+                               info='')
+        uxyz.sphere(r0=(0 * um, 0 * um, 0 * um),
+                    radius=(10 * um, 30 * um, 50 * um),
+                    refraction_index=2,
+                    angles=(0 * degrees, 0 * degrees, 45 * degrees))
         uxyz.incident_field(t1)
-        # uxyz.draw_refraction_index()
+        uxyz.draw_refraction_index()
         assert True
