@@ -27,6 +27,7 @@ if not os.path.exists(newpath):
 
 
 class Test_Scalar_masks_XZ(object):
+
     def test_extrude_mask_z_n_var(self):
         """
         Here the refraction index is a function of positions z
@@ -46,12 +47,11 @@ class Test_Scalar_masks_XZ(object):
         z0 = 10 * um
         z1 = 50 * um
         v_globals = dict(z0=z0, z1=z1)
-        t1.extrude_mask(
-            t=t0,
-            z0=z0,
-            z1=z1,
-            refraction_index='1+0.25*(z-z0)/(z1-z0)',
-            v_globals=v_globals)
+        t1.extrude_mask(t=t0,
+                        z0=z0,
+                        z1=z1,
+                        refraction_index='1+0.25*(z-z0)/(z1-z0)',
+                        v_globals=v_globals)
         t1.draw_refraction_index(draw_borders=False, )
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -74,8 +74,11 @@ class Test_Scalar_masks_XZ(object):
         z0 = 10 * um
         z1 = 50 * um
         v_globals = dict(z0=z0, z1=z1)
-        t1.extrude_mask(
-            t=t0, z0=z0, z1=z1, refraction_index=1.5, v_globals=v_globals)
+        t1.extrude_mask(t=t0,
+                        z0=z0,
+                        z1=z1,
+                        refraction_index=1.5,
+                        v_globals=v_globals)
         t1.draw_refraction_index(draw_borders=False, )
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -96,14 +99,13 @@ class Test_Scalar_masks_XZ(object):
         v_globals = {'um': 1, 'np': np}
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.mask_from_function(
-            r0=(0, 0),
-            refraction_index=1.5,
-            f1=f1,
-            f2=f2,
-            z_sides=z_sides,
-            angle=0 * degrees,
-            v_globals=v_globals)
+        t1.mask_from_function(r0=(0, 0),
+                              refraction_index=1.5,
+                              f1=f1,
+                              f2=f2,
+                              z_sides=z_sides,
+                              angle=0 * degrees,
+                              v_globals=v_globals)
 
         t1.draw_refraction_index()
 
@@ -161,8 +163,11 @@ class Test_Scalar_masks_XZ(object):
         Fs = ['Xrot<3*um', 'Xrot>-3*um', 'Zrot>25*um', 'Zrot<1750*um']
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength, n_background=1)
 
-        t1.object_by_surfaces(
-            r0, refraction_index, Fs, angle=0 * degrees, v_globals={})
+        t1.object_by_surfaces(r0,
+                              refraction_index,
+                              Fs,
+                              angle=0 * degrees,
+                              v_globals={})
 
         t1.draw_refraction_index(draw_borders=True)
 
@@ -185,11 +190,16 @@ class Test_Scalar_masks_XZ(object):
         z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = 50 * um
 
-        t0 = Scalar_mask_XZ(
-            x=x0, z=z0, wavelength=wavelength, n_background=1.0)
+        t0 = Scalar_mask_XZ(x=x0,
+                            z=z0,
+                            wavelength=wavelength,
+                            n_background=1.0)
 
-        pn = dict(
-            n_out=1.5, n_center=4, cx=0 * um, cz=100 * um, radius=75 * um)
+        pn = dict(n_out=1.5,
+                  n_center=4,
+                  cx=0 * um,
+                  cz=100 * um,
+                  radius=75 * um)
 
         center = (pn['cx'], pn['cz'])
         radius = pn['radius']
@@ -197,11 +207,10 @@ class Test_Scalar_masks_XZ(object):
         ref_index = "{p[n_out]}+({p[n_center]}-{p[n_out]})*(1-((X-{p[cx]})**2+(Z-{p[cz]})**2)/{p[radius]}**2)".format(
             p=pn)
 
-        t0.sphere(
-            r0=center,
-            radius=(radius, radius),
-            refraction_index=ref_index,
-            angle=0)
+        t0.sphere(r0=center,
+                  radius=(radius, radius),
+                  refraction_index=ref_index,
+                  angle=0)
 
         t0.draw_refraction_index(draw_borders=False, scale='equal')
 
@@ -226,12 +235,11 @@ class Test_Scalar_masks_XZ(object):
         z_max = 50 * um
         v_globals = dict(np=np)
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength, n_background=1)
-        t1.extrude_mask(
-            t=t0,
-            z0=z_min,
-            z1=z_max,
-            refraction_index='1+0.25*np.abs(x/200)**2',
-            v_globals=v_globals)
+        t1.extrude_mask(t=t0,
+                        z0=z_min,
+                        z1=z_max,
+                        refraction_index='1+0.25*np.abs(x/200)**2',
+                        v_globals=v_globals)
         t1.draw_refraction_index(draw_borders=False)
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -248,11 +256,16 @@ class Test_Scalar_masks_XZ(object):
         z0 = np.linspace(0 * um, 400 * um, 256)
         wavelength = 50 * um
 
-        t0 = Scalar_mask_XZ(
-            x=x0, z=z0, wavelength=wavelength, n_background=1.0)
+        t0 = Scalar_mask_XZ(x=x0,
+                            z=z0,
+                            wavelength=wavelength,
+                            n_background=1.0)
 
-        pn = dict(
-            n_out=1.5, n_center=4, cx=0 * um, cz=100 * um, radius=75 * um)
+        pn = dict(n_out=1.5,
+                  n_center=4,
+                  cx=0 * um,
+                  cz=100 * um,
+                  radius=75 * um)
 
         center = (pn['cx'], pn['cz'])
         radius = pn['radius']
@@ -260,13 +273,12 @@ class Test_Scalar_masks_XZ(object):
         ref_index = "{p[n_out]}+({p[n_center]}-{p[n_out]})*(1-((X-{p[cx]})**2+(Z-{p[cz]})**2)/{p[radius]}**2)".format(
             p=pn)
 
-        t0.sphere(
-            r0=center,
-            radius=(radius, radius),
-            refraction_index=ref_index,
-            angle=0)
+        t0.sphere(r0=center,
+                  radius=(radius, radius),
+                  refraction_index=ref_index,
+                  angle=0)
 
-        t0.discretize_refraction_index(n_layers=np.linspace(1.5, 4, 5))
+        t0.discretize_refraction_index(num_layers=6)
 
         t0.draw_refraction_index(draw_borders=False, scale='equal')
 
@@ -288,26 +300,23 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength, n_background=1)
 
-        t1.sphere(
-            r0=(0, 100 * um),
-            radius=(40 * um, 40 * um),
-            refraction_index=2.5,
-            angle=0)
+        t1.sphere(r0=(0, 100 * um),
+                  radius=(40 * um, 40 * um),
+                  refraction_index=2.5,
+                  angle=0)
 
-        t1.sphere(
-            r0=(0, 100 * um),
-            radius=(10 * um, 10 * um),
-            refraction_index=1,
-            angle=0)
+        t1.sphere(r0=(0, 100 * um),
+                  radius=(10 * um, 10 * um),
+                  refraction_index=1,
+                  angle=0)
 
         for pos_slit in [200, 250, 300, 350]:
-            t1.slit(
-                r0=(0 * um, pos_slit * um),
-                aperture=100 * um,
-                depth=10 * um,
-                refraction_index=1.5 - 1.5j,
-                refraction_index_center='',
-                angle=0 * degrees)
+            t1.slit(r0=(0 * um, pos_slit * um),
+                    aperture=100 * um,
+                    depth=10 * um,
+                    refraction_index=1.5 - 1.5j,
+                    refraction_index_center='',
+                    angle=0 * degrees)
 
         t1.draw_refraction_index(draw_borders=False, scale='equal')
 
@@ -331,8 +340,10 @@ class Test_Scalar_masks_XZ(object):
         t0.double_slit(x0=0, size=20 * um, separation=50 * um)
         t0.draw()
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength, n_background=1)
-        t1.extrude_mask(
-            t=t0, z0=10 * um, z1=50 * um, refraction_index=1.5 - 1.5j)
+        t1.extrude_mask(t=t0,
+                        z0=10 * um,
+                        z1=50 * um,
+                        refraction_index=1.5 - 1.5j)
         t1.draw_refraction_index(draw_borders=True)
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -351,12 +362,11 @@ class Test_Scalar_masks_XZ(object):
         rel_path1 = "star_hole.png"
         image_name = os.path.join(script_dir, rel_path1)
 
-        t1.image(
-            filename=image_name,
-            n_max=2,
-            n_min=1,
-            angle=0 * degrees,
-            invert=False)
+        t1.image(filename=image_name,
+                 n_max=2,
+                 n_min=1,
+                 angle=0 * degrees,
+                 invert=False)
         t1.draw_refraction_index()
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -371,11 +381,10 @@ class Test_Scalar_masks_XZ(object):
         wavelength = .5 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.semi_plane(
-            r0=(0, 0),
-            refraction_index=2,
-            angle=0 * degrees,
-            rotation_point=None)
+        t1.semi_plane(r0=(0, 0),
+                      refraction_index=2,
+                      angle=0 * degrees,
+                      rotation_point=None)
         t1.draw_refraction_index()
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -390,12 +399,11 @@ class Test_Scalar_masks_XZ(object):
         wavelength = .5 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.layer(
-            r0=(50, 0),
-            depth=75 * um,
-            refraction_index=2,
-            angle=0 * degrees,
-            rotation_point=None)
+        t1.layer(r0=(50, 0),
+                 depth=75 * um,
+                 refraction_index=2,
+                 angle=0 * degrees,
+                 rotation_point=None)
         t1.draw_refraction_index()
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -410,11 +418,10 @@ class Test_Scalar_masks_XZ(object):
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.rectangle(
-            r0=(0 * um, 100 * um),
-            size=(150 * um, 50 * um),
-            angle=0 * degrees,
-            refraction_index=1.5)
+        t1.rectangle(r0=(0 * um, 100 * um),
+                     size=(150 * um, 50 * um),
+                     angle=0 * degrees,
+                     refraction_index=1.5)
         t1.draw_refraction_index()
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -430,13 +437,12 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        t1.slit(
-            r0=(0 * um, 50 * um),
-            aperture=50 * um,
-            depth=20 * um,
-            refraction_index=1.5 + 1j,
-            refraction_index_center='',
-            angle=0 * degrees)
+        t1.slit(r0=(0 * um, 50 * um),
+                aperture=50 * um,
+                depth=20 * um,
+                refraction_index=1.5 + 1j,
+                refraction_index_center='',
+                angle=0 * degrees)
 
         t1.draw_refraction_index()
 
@@ -453,11 +459,10 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        t1.sphere(
-            r0=(0, 100 * um),
-            radius=(75 * um, 75 * um),
-            refraction_index=1.5,
-            angle=0 * degrees)
+        t1.sphere(r0=(0, 100 * um),
+                  radius=(75 * um, 75 * um),
+                  refraction_index=1.5,
+                  angle=0 * degrees)
 
         t1.draw_refraction_index()
 
@@ -473,14 +478,14 @@ class Test_Scalar_masks_XZ(object):
         wavelength = .5 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.semi_sphere(
-            r0=(0, 0),
-            radius=(100, 100),
-            refraction_index=2,
-            angle=0 * degrees)
+        t1.semi_sphere(r0=(0, 0),
+                       radius=(100, 100),
+                       refraction_index=2,
+                       angle=0 * degrees)
 
-        t1.draw_refraction_index(
-            draw_borders=True, min_incr=0.01, scale='equal')
+        t1.draw_refraction_index(draw_borders=True,
+                                 min_incr=0.01,
+                                 scale='equal')
 
         t1.save_data(filename=filename + '.npz', add_name='')
         save_figure_test(newpath, func_name, add_name='')
@@ -502,13 +507,12 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        t1.wedge(
-            r0=(0, 0),
-            length=100 * um,
-            refraction_index=1.5,
-            angle_wedge=22.5 * degrees,
-            angle=0 * degrees,
-            rotation_point=None)
+        t1.wedge(r0=(0, 0),
+                 length=100 * um,
+                 refraction_index=1.5,
+                 angle_wedge=22.5 * degrees,
+                 angle=0 * degrees,
+                 rotation_point=None)
         t1.draw_refraction_index()
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -523,12 +527,11 @@ class Test_Scalar_masks_XZ(object):
         wavelength = 2 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.prism(
-            r0=(100 * um, 150 * um),
-            length=200 * um,
-            refraction_index=2,
-            angle_prism=60 * degrees,
-            angle=90 * degrees)
+        t1.prism(r0=(100 * um, 150 * um),
+                 length=200 * um,
+                 refraction_index=2,
+                 angle_prism=60 * degrees,
+                 angle=90 * degrees)
         t1.draw_refraction_index()
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -543,12 +546,11 @@ class Test_Scalar_masks_XZ(object):
         wavelength = 4 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.biprism(
-            r0=(0, 0),
-            length=200 * um,
-            height=50 * um,
-            refraction_index=1.5,
-            angle=0)
+        t1.biprism(r0=(0, 0),
+                   length=200 * um,
+                   height=50 * um,
+                   refraction_index=1.5,
+                   angle=0)
         t1.draw_refraction_index(draw_borders=True, scale='equal')
 
         t1.save_data(filename=filename + '.npz', add_name='')
@@ -564,17 +566,16 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        t1.ronchi_grating(
-            period=50 * um,
-            fill_factor=.5,
-            length=500 * um,
-            height=20 * um,
-            r0=(0 * um, 100 * um),
-            Dx=2 * um,
-            refraction_index=1.5 + 0.5j,
-            heigth_substrate=25 * um,
-            refraction_index_substrate=1.5,
-            angle=0 * degrees)
+        t1.ronchi_grating(period=50 * um,
+                          fill_factor=.5,
+                          length=500 * um,
+                          height=20 * um,
+                          r0=(0 * um, 100 * um),
+                          Dx=2 * um,
+                          refraction_index=1.5 + 0.5j,
+                          heigth_substrate=25 * um,
+                          refraction_index_substrate=1.5,
+                          angle=0 * degrees)
 
         t1.draw_refraction_index()
 
@@ -603,8 +604,10 @@ class Test_Scalar_masks_XZ(object):
         t2 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength, n_background=1)
 
         t2.extrude_mask(t=t0, z0=10 * um, z1=50 * um, refraction_index=1.5)
-        t2.extrude_mask(
-            t=t1, z0=50 * um, z1=55.5 * um, refraction_index=1.5 - 1.5)
+        t2.extrude_mask(t=t1,
+                        z0=50 * um,
+                        z1=55.5 * um,
+                        refraction_index=1.5 - 1.5)
 
         t2.draw_refraction_index(draw_borders=False)
 
@@ -621,15 +624,14 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        t1.sine_grating(
-            period=20 * um,
-            heigth_sine=10 * um,
-            heigth_substrate=100 * um,
-            r0=(0 * um, 200 * um),
-            length=500 * um,
-            Dx=2 * um,
-            refraction_index=1.5,
-            angle=0 * degrees)
+        t1.sine_grating(period=20 * um,
+                        heigth_sine=10 * um,
+                        heigth_substrate=100 * um,
+                        r0=(0 * um, 200 * um),
+                        length=500 * um,
+                        Dx=2 * um,
+                        refraction_index=1.5,
+                        angle=0 * degrees)
 
         t1.draw_refraction_index()
 
@@ -645,12 +647,11 @@ class Test_Scalar_masks_XZ(object):
         wavelength = .6 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.probe(
-            r0=(0, 50 * um),
-            base=10 * um,
-            length=200 * um,
-            refraction_index=1.5,
-            angle=0 * degrees)
+        t1.probe(r0=(0, 50 * um),
+                 base=10 * um,
+                 length=200 * um,
+                 refraction_index=1.5,
+                 angle=0 * degrees)
 
         t1.draw_refraction_index()
 
@@ -667,14 +668,13 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        focal = t1.lens_plane_convergent(
-            r0=(0, -50),
-            aperture=50 * um,
-            radius=50 * um,
-            thickness=50 * um,
-            refraction_index=1.5,
-            angle=0 * degrees,
-            mask=(10 * um, 3 + 0.05j))
+        focal = t1.lens_plane_convergent(r0=(0, -50),
+                                         aperture=50 * um,
+                                         radius=50 * um,
+                                         thickness=50 * um,
+                                         refraction_index=1.5,
+                                         angle=0 * degrees,
+                                         mask=(10 * um, 3 + 0.05j))
         print("focus distance f={} um".format(focal))
         t1.draw_refraction_index(scale='equal')
 
@@ -691,14 +691,13 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        focal = t1.lens_convergent(
-            r0=(0, 0),
-            aperture=300 * um,
-            radius=(1000 * um, -250 * um),
-            thickness=100 * um,
-            refraction_index=2,
-            angle=0 * degrees,
-            mask=(10 * um, 3 + 0.05j))
+        focal = t1.lens_convergent(r0=(0, 0),
+                                   aperture=300 * um,
+                                   radius=(1000 * um, -250 * um),
+                                   thickness=100 * um,
+                                   refraction_index=2,
+                                   angle=0 * degrees,
+                                   mask=(10 * um, 3 + 0.05j))
         print("focus distance f={} um".format(focal))
         t1.draw_refraction_index(scale='equal')
 
@@ -715,14 +714,13 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        focal = t1.lens_plane_divergent(
-            r0=(0, 0),
-            aperture=100 * um,
-            radius=50 * um,
-            thickness=25 * um,
-            refraction_index=2,
-            angle=0 * degrees,
-            mask=(10 * um, 3 + 0.05j))
+        focal = t1.lens_plane_divergent(r0=(0, 0),
+                                        aperture=100 * um,
+                                        radius=50 * um,
+                                        thickness=25 * um,
+                                        refraction_index=2,
+                                        angle=0 * degrees,
+                                        mask=(10 * um, 3 + 0.05j))
         print("focus distance f={} um".format(focal))
         t1.draw_refraction_index(scale='equal')
 
@@ -739,14 +737,13 @@ class Test_Scalar_masks_XZ(object):
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
 
-        focal = t1.lens_divergent(
-            r0=(0, 0),
-            aperture=100 * um,
-            radius=(-50 * um, 50 * um),
-            thickness=25 * um,
-            refraction_index=1.5,
-            angle=0 * degrees,
-            mask=(10 * um, 3 + 0.05j))
+        focal = t1.lens_divergent(r0=(0, 0),
+                                  aperture=100 * um,
+                                  radius=(-50 * um, 50 * um),
+                                  thickness=25 * um,
+                                  refraction_index=1.5,
+                                  angle=0 * degrees,
+                                  mask=(10 * um, 3 + 0.05j))
         print("focus distance f={} um".format(focal))
         t1.draw_refraction_index(scale='equal')
 
@@ -762,14 +759,13 @@ class Test_Scalar_masks_XZ(object):
         wavelength = 0.6238 * um
 
         t1 = Scalar_mask_XZ(x=x0, z=z0, wavelength=wavelength)
-        t1.rough_sheet(
-            r0=(0 * um, 0 * um),
-            size=(200 * um, 25 * um),
-            t=10 * um,
-            s=10 * um,
-            refraction_index=1.5,
-            angle=0,
-            rotation_point=None)
+        t1.rough_sheet(r0=(0 * um, 0 * um),
+                       size=(200 * um, 25 * um),
+                       t=10 * um,
+                       s=10 * um,
+                       refraction_index=1.5,
+                       angle=0,
+                       rotation_point=None)
         t1.draw_refraction_index()
 
         t1.save_data(filename=filename + '.npz', add_name='')
